@@ -53,10 +53,12 @@ class DateParserIT(DateParser):
         "prima del": Date.MOD_BEFORE,
         "prima": Date.MOD_BEFORE,
         "dopo del": Date.MOD_AFTER,
+        "dopo il": Date.MOD_AFTER,
         "dopo": Date.MOD_AFTER,
         "approssimativamente": Date.MOD_ABOUT,
         "apross.": Date.MOD_ABOUT,
         "apross": Date.MOD_ABOUT,
+        "circa nel": Date.MOD_ABOUT,
         "circa il": Date.MOD_ABOUT,
         "circa": Date.MOD_ABOUT,
         "ca.": Date.MOD_ABOUT,
