@@ -23,37 +23,38 @@
 Class handling language-specific selection for date parser and displayer.
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import os
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # set up logging
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import logging
+
 log = logging.getLogger(".gen.datehandler")
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ._dateparser import DateParser
 from ._datedisplay import DateDisplay, DateDisplayEn, DateDisplayGB
 from ..constfunc import win
 from ..const import GRAMPS_LOCALE as glocale
 from ..utils.grampslocale import GrampsLocale
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Constants
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 LANG = glocale.calendar
 
 # If LANG contains ".UTF-8" use only the part to the left of "."
@@ -66,7 +67,7 @@ if not LANG:
         LANG = os.environ["LANG"]
 
 if LANG:
-    LANG_SHORT = LANG.split('_')[0]
+    LANG_SHORT = LANG.split("_")[0]
 else:
     LANG_SHORT = "C"
 
@@ -74,39 +75,40 @@ LANG = str(LANG)
 LANG_SHORT = str(LANG_SHORT)
 
 LANG_TO_PARSER = {
-    'C'                     : DateParser,
-    }
+    "C": DateParser,
+}
 
 LANG_TO_DISPLAY = {
-    'C'                     : DateDisplayEn,
-    'ko_KR'                 : DateDisplay,
-    }
+    "C": DateDisplayEn,
+    "ko_KR": DateDisplay,
+}
 
-main_locale = { } # this will be augmented by calls to register_datehandler
+main_locale = {}  # this will be augmented by calls to register_datehandler
 
-locale_tformat = {} # locale "tformat" (date format) strings
+locale_tformat = {}  # locale "tformat" (date format) strings
 
 for no_handler in (
-    ('C', ('%d/%m/%Y',)),
-    ('eo_EO', 'eo', 'Esperanto', ('%d/%m/%Y',)), # 'eo_EO' is a placeholder
-    ('he_IL', 'he', 'Hebrew', ('%d/%m/%Y',)),
-    ('sq_AL', 'sq', 'Albanian', ('%Y/%b/%d',)),
-    ('ta_IN', 'ta', 'Tamil', ('%A %d %B %Y',)),
-    ('tr_TR', 'tr', 'Turkish', ('%d/%m/%Y',)),
-    ('vi_VN', 'vi', 'Vietnamese', ('%d/%m/%Y',)),
-    ):
-    format_string = ''
+    ("C", ("%d/%m/%Y",)),
+    ("eo_EO", "eo", "Esperanto", ("%d/%m/%Y",)),  # 'eo_EO' is a placeholder
+    ("sq_AL", "sq", "Albanian", ("%Y/%b/%d",)),
+    ("ta_IN", "ta", "Tamil", ("%A %d %B %Y",)),
+    ("tr_TR", "tr", "Turkish", ("%d/%m/%Y",)),
+    ("vi_VN", "vi", "Vietnamese", ("%d/%m/%Y",)),
+):
+    format_string = ""
     for possible_format in no_handler:
         if isinstance(possible_format, tuple):
-            format_string = possible_format[0] # pre-seeded date format string
+            format_string = possible_format[0]  # pre-seeded date format string
             # maintain legacy gramps transformations
-            format_string = format_string.replace('%y','%Y').replace('-', '/')
+            format_string = format_string.replace("%y", "%Y").replace("-", "/")
     for lang_str in no_handler:
-        if isinstance(lang_str, tuple): continue
+        if isinstance(lang_str, tuple):
+            continue
         main_locale[lang_str] = no_handler[0]
-        locale_tformat[lang_str] = format_string # locale's date format string
+        locale_tformat[lang_str] = format_string  # locale's date format string
 
-def register_datehandler(locales,parse_class,display_class):
+
+def register_datehandler(locales, parse_class, display_class):
     """
     Registers the passed date parser class and date displayer
     classes with the specified language locales.
@@ -123,25 +125,27 @@ def register_datehandler(locales,parse_class,display_class):
     :param display_class: Class to be associated with displaying
     :type display_class: :class:`.DateDisplay`
     """
-    format_string = ''
-    for possible_format in locales: # allow possibly embedding a date format
+    format_string = ""
+    for possible_format in locales:  # allow possibly embedding a date format
         if isinstance(possible_format, tuple):
-            format_string = possible_format[0] # pre-seeded date format string
+            format_string = possible_format[0]  # pre-seeded date format string
             # maintain legacy gramps transformations
-            format_string = format_string.replace('%y','%Y').replace('-', '/')
+            format_string = format_string.replace("%y", "%Y").replace("-", "/")
     for lang_str in locales:
-        if isinstance(lang_str, tuple): continue
+        if isinstance(lang_str, tuple):
+            continue
         LANG_TO_PARSER[lang_str] = parse_class
         LANG_TO_DISPLAY[lang_str] = display_class
         main_locale[lang_str] = locales[0]
-        locale_tformat[lang_str] = format_string # locale's date format string
+        locale_tformat[lang_str] = format_string  # locale's date format string
 
     parse_class._locale = display_class._locale = GrampsLocale(lang=locales[0])
 
-register_datehandler(
-    ('en_GB', 'English_United Kingdom', ("%d/%m/%y",)),
-    DateParser, DateDisplayGB)
 
 register_datehandler(
-    ('en_US', 'en', 'English_United States', ("%m/%d/%y",)),
-    DateParser, DateDisplayEn)
+    ("en_GB", "English_United Kingdom", ("%d/%m/%y",)), DateParser, DateDisplayGB
+)
+
+register_datehandler(
+    ("en_US", "en", "English_United States", ("%m/%d/%y",)), DateParser, DateDisplayEn
+)
