@@ -21,48 +21,59 @@
 #
 # gen.filters.rules/_HasGalleryBase.py
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ...const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from . import Rule
 
-#-------------------------------------------------------------------------
-# "People who have images"
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
+#
+# Typing modules
+#
+# -------------------------------------------------------------------------
+from ...lib.mediabase import MediaBase
+from ...db import Database
+
+
+# -------------------------------------------------------------------------
+# "Objects that have images"
+# -------------------------------------------------------------------------
 class HasGalleryBase(Rule):
     """Objects who have Media Object"""
 
-    labels = [  _('Number of instances:'), _('Number must be:')]
-    name = 'Object with <count> Media references'
+    labels = [_("Number of instances:"), _("Number must be:")]
+    name = "Object with <count> Media references"
     description = "Matches objects with certain number of items in the gallery"
-    category = _('General filters')
+    category = _("General filters")
 
-    def prepare(self, db, user):
+    def prepare(self, db: Database, user):
         # things we want to do just once, not for every handle
-        if  self.list[1] == 'less than':
+        if self.list[1] == "less than":
             self.count_type = 0
-        elif self.list[1] == 'greater than':
+        elif self.list[1] == "greater than":
             self.count_type = 2
         else:
-            self.count_type = 1 # "equal to"
+            self.count_type = 1  # "equal to"
 
         self.userSelectedCount = int(self.list[0])
 
-    def apply(self, db, obj):
-        count = len( obj.get_media_list())
-        if self.count_type == 0:     # "less than"
+    def apply_to_one(self, db: Database, obj: MediaBase) -> bool:
+        count = len(obj.media_list)
+        if self.count_type == 0:  # "less than"
             return count < self.userSelectedCount
-        elif self.count_type == 2:   # "greater than"
+        elif self.count_type == 2:  # "greater than"
             return count > self.userSelectedCount
         # "equal to"
         return count == self.userSelectedCount
