@@ -41,6 +41,15 @@ from ...const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
 
 
+# -------------------------------------------------------------------------
+#
+# Typing modules
+#
+# -------------------------------------------------------------------------
+from typing import Any, Union
+from ...db import Database
+
+
 # -------------------------------------------------------------------------
 #
 # MatchesFilter
@@ -59,8 +68,9 @@ class MatchesFilterBase(Rule):
     name = "Objects matching the <filter>"
     description = "Matches objects matched by the specified filter name"
     category = _("General filters")
+    namespace: Union[str, None] = None
 
-    def prepare(self, db, user):
+    def prepare(self, db: Database, user):
         if gramps.gen.filters.CustomFilters:
             filters = gramps.gen.filters.CustomFilters.get_filters_dict(self.namespace)
             if self.list[0] in filters:
@@ -85,12 +95,12 @@ class MatchesFilterBase(Rule):
                 for rule in filt.flist:
                     rule.requestreset()
 
-    def apply(self, db, obj):
+    def apply_to_one(self, db: Database, obj: Any) -> bool:
         if gramps.gen.filters.CustomFilters:
             filters = gramps.gen.filters.CustomFilters.get_filters_dict(self.namespace)
             if self.list[0] in filters:
                 filt = filters[self.list[0]]
-                return filt.check(db, obj.handle)
+                return filt.apply_to_one(db, obj)
         return False
 
     def find_filter(self):
