@@ -21,30 +21,33 @@
 Rule that checks for an event with a particular tag.
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .._hastagbase import HasTagBase
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # HasTag
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class HasTag(HasTagBase):
     """
     Rule that checks for an event with a particular tag.
     """
-    labels      = [ _('Tag:') ]
-    name        = _('Events with the <tag>')
+
+    labels = [_("Tag:")]
+    name = _("Events with the <tag>")
     description = _("Matches events with the particular tag")
