@@ -19,29 +19,32 @@
 #
 # gen.filters.rules/Event/_MatchesSourceConfidence.py
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.sgettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .._matchessourceconfidencebase import MatchesSourceConfidenceBase
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 # "Confidence level"
 # Sources of an attribute of an event are ignored
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class MatchesSourceConfidence(MatchesSourceConfidenceBase):
     """Events matching a specific confidence level on its 'direct' source references"""
 
-    labels    = [_('Confidence level:')]
-    name        = _('Events with at least one direct source >= <confidence level>')
-    description = _("Matches events with at least one direct source with confidence level(s)")
-
+    labels = [_("Confidence level:")]
+    name = _("Events with at least one direct source >= <confidence level>")
+    description = _(
+        "Matches events with at least one direct source with confidence level(s)"
+    )
