@@ -18,28 +18,38 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+from ....db import Database
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .. import HasGrampsId
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # HasIdOf
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class HasIdOf(HasGrampsId):
-    """Rule that checks for a note with a specific GRAMPS ID"""
+    """Rule that checks for a note with a specific Gramps ID"""
 
-    name        = _('Note with <Id>')
+    name = _("Note with <Id>")
     description = _("Matches a note with a specified Gramps ID")
+
+    def prepare(self, db: Database, user):
+        data = db._get_raw_note_from_id_data(self.list[0])
+        if data:
+            self.selected_handles = set([data.handle])
+        else:
+            self.selected_handles = set([])
