@@ -18,41 +18,62 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# -------------------------------------------------------------------------
-#
-# Standard Python modules
-#
-# -------------------------------------------------------------------------
+"""
+Rule that checks for a note of a particular type.
+"""
 
 # -------------------------------------------------------------------------
 #
 # Gramps modules
 #
 # -------------------------------------------------------------------------
+from ....const import GRAMPS_LOCALE as glocale
 from ....lib.notetype import NoteType
 from .. import Rule
-from ....const import GRAMPS_LOCALE as glocale
 
 _ = glocale.translation.gettext
 
 
+# -------------------------------------------------------------------------
+#
+# Typing modules
+#
+# -------------------------------------------------------------------------
+from ....lib import Note
+from ....db import Database
+
+
 # -------------------------------------------------------------------------
 #
 # HasType
 #
 # -------------------------------------------------------------------------
 class HasType(Rule):
-    """Rule that checks for a note of a particular type."""
+    """
+    Rule that checks for a note of a particular type.
+    """
 
     labels = [_("Note type:")]
     name = _("Notes with the particular type")
     description = _("Matches notes with the particular type ")
     category = _("General filters")
 
-    def apply(self, db, note):
-        if not self.list[0]:
-            return False
-        else:
-            specified_type = NoteType()
-            specified_type.set_from_xml_str(self.list[0])
-            return note.get_type() == specified_type
+    def __init__(self, arg, use_regex=False, use_case=False):
+        super().__init__(arg, use_regex, use_case)
+        self.note_type = None
+
+    def prepare(self, db: Database, user):
+        """
+        Prepare the rule. Things we only want to do once.
+        """
+        if self.list[0]:
+            self.note_type = NoteType()
+            self.note_type.set_from_xml_str(self.list[0])
+
+    def apply_to_one(self, _db: Database, obj: Note) -> bool:
+        """
+        Apply the rule. Return True on a match.
+        """
+        if self.note_type:
+            return obj.type == self.note_type
+        return False
