@@ -17,24 +17,30 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-# gen.filters.rules/Person/_HasNameType.py
 
-# -------------------------------------------------------------------------
-#
-# Standard Python modules
-#
-# -------------------------------------------------------------------------
-from ....const import GRAMPS_LOCALE as glocale
-
-_ = glocale.translation.gettext
+"""
+Rule that checks the type of name.
+"""
 
 # -------------------------------------------------------------------------
 #
 # Gramps modules
 #
 # -------------------------------------------------------------------------
-from .. import Rule
+from ....const import GRAMPS_LOCALE as glocale
 from ....lib.nametype import NameType
+from .. import Rule
+
+_ = glocale.translation.gettext
+
+
+# -------------------------------------------------------------------------
+#
+# Typing modules
+#
+# -------------------------------------------------------------------------
+from ....lib import Person
+from ....db import Database
 
 
 # -------------------------------------------------------------------------
@@ -43,19 +49,33 @@ from ....lib.nametype import NameType
 #
 # -------------------------------------------------------------------------
 class HasNameType(Rule):
-    """Rule that checks the type of name"""
+    """
+    Rule that checks the type of name.
+    """
 
     labels = [_("Name type:")]
     name = _("People with the <Name type>")
     description = _("Matches people with a type of name")
     category = _("General filters")
 
-    def apply(self, db, person):
-        if not self.list[0]:
-            return False
-        for name in [person.get_primary_name()] + person.get_alternate_names():
-            specified_type = NameType()
-            specified_type.set_from_xml_str(self.list[0])
-            if name.get_type() == specified_type:
-                return True
+    def __init__(self, arg, use_regex=False, use_case=False):
+        super().__init__(arg, use_regex, use_case)
+        self.name_type = None
+
+    def prepare(self, db: Database, user):
+        """
+        Prepare the rule. Things we only want to do once.
+        """
+        if self.list[0]:
+            self.name_type = NameType()
+            self.name_type.set_from_xml_str(self.list[0])
+
+    def apply_to_one(self, _db: Database, obj: Person) -> bool:
+        """
+        Apply the rule. Return True on a match.
+        """
+        if self.name_type:
+            for name in [obj.primary_name] + obj.alternate_names:
+                if name.type == self.name_type:
+                    return True
         return False
