@@ -18,31 +18,33 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ._hastextmatchingsubstringof import HasTextMatchingSubstringOf
 
-#-------------------------------------------------------------------------
-# "HasTextMatchingRegexOf"
-#-------------------------------------------------------------------------
-class HasTextMatchingRegexpOf(HasTextMatchingSubstringOf):
-    """This is wrapping HasTextMatchingSubstringOf to enable the regex_match 
-    parameter.
-    
-    """
-    def __init__(self, list, use_regex=False):
-        HasTextMatchingSubstringOf.__init__(self, list, use_regex)
 
-    def prepare(self,db):
+# -------------------------------------------------------------------------
+# "HasTextMatchingRegexOf"
+# -------------------------------------------------------------------------
+class HasTextMatchingRegexpOf(HasTextMatchingSubstringOf):
+    """This is wrapping HasTextMatchingSubstringOf to enable the regex_match
+    parameter.
+
+    """
+
+    def __init__(self, list, use_regex=False, use_case=False):
+        HasTextMatchingSubstringOf.__init__(self, list, use_regex, use_case)
+
+    def prepare(self, db, user):
         self.db = db
         self.person_map = set()
         self.event_map = set()
