@@ -38,6 +38,17 @@ except NameError:
 from .. import Rule
 
 
+# -------------------------------------------------------------------------
+#
+# Typing modules
+#
+# -------------------------------------------------------------------------
+from typing import List, Set, Dict
+from ....lib import Person
+from ....db import Database
+from ....types import PersonHandle, FamilyHandle
+
+
 # -------------------------------------------------------------------------
 #
 # RelationshipPathBetween
@@ -58,56 +69,57 @@ class RelationshipPathBetweenBookmarks(Rule):
         "path(s) between bookmarked persons."
     )
 
-    def prepare(self, db, user):
+    def prepare(self, db: Database, user):
         self.db = db
-        self.map = set()
+        self.selected_handles: Set[PersonHandle] = set()
         bookmarks = db.get_bookmarks().get()
-        if len(bookmarks) == 0:
-            self.apply = lambda db, p: False
-        else:
-            self.bookmarks = set(bookmarks)
+        self.bookmarks: Set[PersonHandle] = set(bookmarks)
         try:
             self.init_list()
         except:
             pass
 
     def reset(self):
-        self.map.clear()
+        self.selected_handles.clear()
 
     #
     # Returns a name, given a handle.
-    def hnm(self, handle):
+    def hnm(self, handle: PersonHandle):
         try:
             person = self.db.get_person_from_handle(handle)
         except:
             return None
         if person is None:
             return None
-        try:
-            name = person.get_primary_name().get_name()
-        except:
+
+        if person.primary_name:
+            return person.primary_name.name
+        else:
             return None
-        return name
 
     #
     # Given a group of individuals, returns all of their parents.
     # The value keyed by the individual handles is the path from
     # the original person up, like generation[gfather]= [son,father,gfather]
-    def parents(self, generation):
+    def parents(self, generation: Dict[PersonHandle, List[PersonHandle]]):
         if len(generation) < 1:
             return None
-        prev_generation = {}
+        prev_generation: Dict[PersonHandle, List[PersonHandle]] = {}
         for handle in generation:
             try:
                 person = self.db.get_person_from_handle(handle)
                 if person is None:
                     continue
-                fam_id = person.get_main_parents_family_handle()
-                family = self.db.get_family_from_handle(fam_id)
+                fam_id = (
+                    person.parent_family_list[0]
+                    if len(person.parent_family_list) > 0
+                    else None
+                )
+                family = self.db.get_family_from_handle(fam_id)  # type: ignore
                 if family is None:
                     continue
-                fhandle = family.get_father_handle()
-                mhandle = family.get_mother_handle()
+                fhandle = family.father_handle
+                mhandle = family.mother_handle
                 if fhandle:
                     prev_generation[fhandle] = generation[handle] + [fhandle]
                 if mhandle:
@@ -119,7 +131,7 @@ class RelationshipPathBetweenBookmarks(Rule):
     #
     # Given two handles for individuals, a list of all individuals
     # in the relationship path between the two.
-    def rel_path_for_two(self, handle1, handle2):
+    def rel_path_for_two(self, handle1: PersonHandle, handle2: PersonHandle):
         # print "rel_path_for_two (", handle1, self.hnm(handle1), ",", handle2, self.hnm(handle2), ")"
         rel_path = {}  # Result map
         gmap1 = {handle1: [handle1]}  # Key is ancestor, value is the path
@@ -149,11 +161,11 @@ class RelationshipPathBetweenBookmarks(Rule):
         # print "  In rel_path_for_two, returning rel_path = ", rel_path
         return rel_path
 
-    def init_list(self):
-        self.map.update(self.bookmarks)
+    def init_list(self) -> None:
+        self.selected_handles.update(self.bookmarks)
         if len(self.bookmarks) < 2:
             return
-        bmarks = list(self.bookmarks)
+        bmarks: List[PersonHandle] = list(self.bookmarks)
 
         # Go through all bookmarked individuals, and mark all
         # of the people in each of the paths betweent them.
@@ -162,9 +174,9 @@ class RelationshipPathBetweenBookmarks(Rule):
             for j in range(i + 1, lb):
                 try:
                     pathmap = self.rel_path_for_two(bmarks[i], bmarks[j])
-                    self.map.update(pathmap)
+                    self.selected_handles.update(pathmap)
                 except:
                     pass
 
-    def apply(self, db, person):
-        return person.handle in self.map
+    def apply_to_one(self, db: Database, person: Person) -> bool:
+        return person.handle in self.selected_handles
