@@ -29,8 +29,6 @@
 # -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
 
-_ = glocale.translation.gettext
-
 # -------------------------------------------------------------------------
 #
 # Gramps modules
@@ -39,6 +37,18 @@ _ = glocale.translation.gettext
 from .. import Rule
 
 
+# -------------------------------------------------------------------------
+#
+# Typing modules
+#
+# -------------------------------------------------------------------------
+from ....lib import Source
+from ....db import Database
+
+
+_ = glocale.translation.gettext
+
+
 # -------------------------------------------------------------------------
 # "People who have images"
 # -------------------------------------------------------------------------
@@ -50,7 +60,7 @@ class HasRepository(Rule):
     description = _("Matches sources with a certain number of repository references")
     category = _("General filters")
 
-    def prepare(self, db, user):
+    def prepare(self, db: Database, user):
         # things we want to do just once, not for every handle
         if self.list[1] == "less than":
             self.count_type = 0
@@ -61,8 +71,8 @@ class HasRepository(Rule):
 
         self.userSelectedCount = int(self.list[0])
 
-    def apply(self, db, obj):
-        count = len(obj.get_reporef_list())
+    def apply_to_one(self, db, obj: Source) -> bool:
+        count = len(obj.reporef_list)
         if self.count_type == 0:  # "less than"
             return count < self.userSelectedCount
         elif self.count_type == 2:  # "greater than"
