@@ -19,36 +19,49 @@
 #
 # gen.filters.rules/Source/_HasRepositoryCallNumberRef.py
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
+# -------------------------------------------------------------------------
+#
+# Typing modules
+#
+# -------------------------------------------------------------------------
+from ....lib import Source
+from ....db import Database
+
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .. import Rule
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 # "Sources which reference repositories by a special Call Name"
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class HasRepositoryCallNumberRef(Rule):
     """Sources which reference repositories by a special Call Number"""
 
-    labels = [ _('Text:')]
+    labels = [_("Text:")]
     name = _('Sources with repository reference containing <text> in "Call Number"')
-    description = _("Matches sources with a repository reference\n"
-                    "containing a substring in \"Call Number\"")
-    category = _('General filters')
+    description = _(
+        "Matches sources with a repository reference\n"
+        'containing a substring in "Call Number"'
+    )
+    category = _("General filters")
     allow_regex = True
 
-    def apply(self, db, obj):
-        for repo_ref in obj.get_reporef_list():
+    def apply_to_one(self, db: Database, obj: Source) -> bool:
+        for repo_ref in obj.reporef_list:
             if self.match_substring(0, repo_ref.call_number):
                 return True
         return False
