@@ -2,7 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
-# Copyright (C) 2013       Nick Hall
+# Copyright (C) 2013,2017  Nick Hall
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,22 +23,25 @@
 Place Reference class for Gramps
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
-from .secondaryobj import SecondaryObject
-from .refbase import RefBase
+# -------------------------------------------------------------------------
+from ..const import GRAMPS_LOCALE as glocale
+from .const import DIFFERENT, EQUAL, IDENTICAL
 from .datebase import DateBase
-from .const import IDENTICAL, EQUAL, DIFFERENT
-from .handle import Handle
+from .refbase import RefBase
+from .secondaryobj import SecondaryObject
 
-#-------------------------------------------------------------------------
+_ = glocale.translation.gettext
+
+
+# -------------------------------------------------------------------------
 #
-# Place References
+# PlaceRef
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class PlaceRef(RefBase, DateBase, SecondaryObject):
     """
     Place reference class.
@@ -58,49 +61,7 @@ class PlaceRef(RefBase, DateBase, SecondaryObject):
         """
         Convert the object to a serialized tuple of data.
         """
-        return (
-            RefBase.serialize(self),
-            DateBase.serialize(self)
-            )
-
-    def to_struct(self):
-        """
-        Convert the data held in this object to a structure (eg,
-        struct) that represents all the data elements.
-        
-        This method is used to recursively convert the object into a
-        self-documenting form that can easily be used for various
-        purposes, including diffs and queries.
-
-        These structures may be primitive Python types (string,
-        integer, boolean, etc.) or complex Python types (lists,
-        tuples, or dicts). If the return type is a dict, then the keys
-        of the dict match the fieldname of the object. If the return
-        struct (or value of a dict key) is a list, then it is a list
-        of structs. Otherwise, the struct is just the value of the
-        attribute.
-
-        :returns: Returns a struct containing the data of the object.
-        :rtype: dict
-        """
-        return {
-            "_class": "PlaceRef",
-            "ref": Handle("Place", self.ref),
-            "date": DateBase.to_struct(self)
-            }
-
-    @classmethod
-    def from_struct(cls, struct):
-        """
-        Given a struct data representation, return a serialized object.
-
-        :returns: Returns a serialized object
-        """
-        default = PlaceRef()
-        return (
-            RefBase.from_struct(struct.get("ref", default.ref)),
-            DateBase.from_struct(struct.get("date", {}))
-            )
+        return (RefBase.serialize(self), DateBase.serialize(self))
 
     def unserialize(self, data):
         """
@@ -111,6 +72,31 @@ class PlaceRef(RefBase, DateBase, SecondaryObject):
         DateBase.unserialize(self, date)
         return self
 
+    @classmethod
+    def get_schema(cls):
+        """
+        Returns the JSON Schema for this class.
+
+        :returns: Returns a dict containing the schema.
+        :rtype: dict
+        """
+        # pylint: disable=import-outside-toplevel
+        from .date import Date
+
+        return {
+            "type": "object",
+            "title": _("Place ref"),
+            "properties": {
+                "_class": {"enum": [cls.__name__]},
+                "ref": {
+                    "type": "string",
+                    "title": _("Handle"),
+                    "maxLength": 50,
+                },
+                "date": Date.get_schema(),
+            },
+        }
+
     def get_text_data_list(self):
         """
         Return the list of all textual attributes of the object.
@@ -133,7 +119,7 @@ class PlaceRef(RefBase, DateBase, SecondaryObject):
         """
         Return the list of child secondary objects that may refer citations.
 
-        :returns: Returns the list of child secondary child objects that may 
+        :returns: Returns the list of child secondary child objects that may
                   refer citations.
         :rtype: list
         """
@@ -143,7 +129,7 @@ class PlaceRef(RefBase, DateBase, SecondaryObject):
         """
         Return the list of child secondary objects that may refer notes.
 
-        :returns: Returns the list of child secondary child objects that may 
+        :returns: Returns the list of child secondary child objects that may
                   refer notes.
         :rtype: list
         """
@@ -153,18 +139,18 @@ class PlaceRef(RefBase, DateBase, SecondaryObject):
         """
         Return the list of (classname, handle) tuples for all directly
         referenced primary objects.
-        
-        :returns: Returns the list of (classname, handle) tuples for referenced 
+
+        :returns: Returns the list of (classname, handle) tuples for referenced
                   objects.
         :rtype: list
         """
-        return [('Place', self.ref)]
+        return [("Place", self.ref)]
 
     def get_handle_referents(self):
         """
-        Return the list of child objects which may, directly or through their 
+        Return the list of child objects which may, directly or through their
         children, reference primary objects..
-        
+
         :returns: Returns the list of objects referencing primary objects.
         :rtype: list
         """
@@ -182,8 +168,6 @@ class PlaceRef(RefBase, DateBase, SecondaryObject):
         """
         if self.ref != other.ref or self.date != other.date:
             return DIFFERENT
-        else:
-            if self.is_equal(other):
-                return IDENTICAL
-            else:
-                return EQUAL
+        if self.is_equal(other):
+            return IDENTICAL
+        return EQUAL
