@@ -24,50 +24,54 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # standard python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import os
 from xml.sax.saxutils import escape
 
+
 def escxml(string):
     """
     Escapes XML special characters.
     """
-    return escape(string, { '"' : '&quot;' } )
+    return escape(string, {'"': "&quot;"})
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .paragraphstyle import ParagraphStyle
 from .fontstyle import FontStyle
 from .tablestyle import TableStyle, TableCellStyle
 from .graphicstyle import GraphicsStyle
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # set up logging
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import logging
+
 log = logging.getLogger(".stylesheet")
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # SAX interface
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from xml.sax import make_parser, handler, SAXParseException
 
-#------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------
 #
 # cnv2color
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 def cnv2color(text):
     """
     converts a hex value in the form of #XXXXXX into a tuple of integers
@@ -76,11 +80,11 @@ def cnv2color(text):
     return (int(text[1:3], 16), int(text[3:5], 16), int(text[5:7], 16))
 
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
 # StyleSheetList
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 class StyleSheetList:
     """
     Interface into the user's defined style sheets. Each StyleSheetList
@@ -96,8 +100,8 @@ class StyleSheetList:
         file - XML file that contains style definitions
         defstyle - default style
         """
-        defstyle.set_name('default')
-        self.map = { "default" : defstyle }
+        defstyle.set_name("default")
+        self.map = {"default": defstyle}
         self.__file = filename
         self.parse()
 
@@ -146,9 +150,9 @@ class StyleSheetList:
         """
         with open(self.__file, "w") as xml_file:
             xml_file.write('<?xml version="1.0" encoding="utf-8"?>\n')
-            xml_file.write('<stylelist>\n')
+            xml_file.write("<stylelist>\n")
 
-            for name in sorted(self.map.keys()): # enable diff of archived ones
+            for name in sorted(self.map.keys()):  # enable diff of archived ones
                 if name == "default":
                     continue
                 sheet = self.map[name]
@@ -166,11 +170,10 @@ class StyleSheetList:
                 for g_name in sorted(sheet.get_draw_style_names()):
                     self.write_graphics_style(xml_file, sheet, g_name)
 
-                xml_file.write('  </sheet>\n')
-            xml_file.write('</stylelist>\n')
+                xml_file.write("  </sheet>\n")
+            xml_file.write("</stylelist>\n")
 
     def write_paragraph_style(self, xml_file, sheet, p_name):
-
         para = sheet.get_paragraph_style(p_name)
 
         # Get variables for substitutions
@@ -185,90 +188,88 @@ class StyleSheetList:
 
         # Write out style definition
         xml_file.write(
-            '    <style name="%s">\n' % escxml(p_name) +
-            '      <font ' +
-                    'face="%d" ' % font.get_type_face() +
-                    'size="%d" ' % font.get_size() +
-                    'italic="%d" ' % font.get_italic() +
-                    'bold="%d" ' % font.get_bold() +
-                    'underline="%d" ' % font.get_underline() +
-                    'color="#%02x%02x%02x" ' % font.get_color() +
-                    '/>\n' +
-            '      <para ' +
-                    'description="%s" ' % escxml(para.get_description()) +
-                    'rmargin="%.3f" ' % rmargin +
-                    'lmargin="%.3f" ' % lmargin +
-                    'first="%.3f" ' % findent +
-                    'tmargin="%.3f" ' % tmargin +
-                    'bmargin="%.3f" ' % bmargin +
-                    'pad="%.3f" ' % padding +
-                    'bgcolor="#%02x%02x%02x" ' % bg_color +
-                    'level="%d" ' % para.get_header_level() +
-                    'align="%d" ' % para.get_alignment() +
-                    'tborder="%d" ' % para.get_top_border() +
-                    'lborder="%d" ' % para.get_left_border() +
-                    'rborder="%d" ' % para.get_right_border() +
-                    'bborder="%d" ' % para.get_bottom_border() +
-                    '/>\n' +
-            '    </style>\n'
+            '    <style name="%s">\n' % escxml(p_name)
+            + "      <font "
+            + 'face="%d" ' % font.get_type_face()
+            + 'size="%d" ' % font.get_size()
+            + 'italic="%d" ' % font.get_italic()
+            + 'bold="%d" ' % font.get_bold()
+            + 'underline="%d" ' % font.get_underline()
+            + 'color="#%02x%02x%02x" ' % font.get_color()
+            + "/>\n"
+            + "      <para "
+            + 'description="%s" ' % escxml(para.get_description())
+            + 'rmargin="%.3f" ' % rmargin
+            + 'lmargin="%.3f" ' % lmargin
+            + 'first="%.3f" ' % findent
+            + 'tmargin="%.3f" ' % tmargin
+            + 'bmargin="%.3f" ' % bmargin
+            + 'pad="%.3f" ' % padding
+            + 'bgcolor="#%02x%02x%02x" ' % bg_color
+            + 'level="%d" ' % para.get_header_level()
+            + 'align="%d" ' % para.get_alignment()
+            + 'tborder="%d" ' % para.get_top_border()
+            + 'lborder="%d" ' % para.get_left_border()
+            + 'rborder="%d" ' % para.get_right_border()
+            + 'bborder="%d" ' % para.get_bottom_border()
+            + "/>\n"
+            + "    </style>\n"
         )
 
     def write_table_style(self, xml_file, sheet, t_name):
-
         t_style = sheet.get_table_style(t_name)
 
         # Write out style definition
         xml_file.write(
-            '    <style name="%s">\n' % escxml(t_name) +
-            '      <table ' +
-                    'description="%s" ' % escxml(t_style.get_description()) +
-                    'width="%d" ' % t_style.get_width() +
-                    'columns="%d"' % t_style.get_columns() +
-                    '>\n')
+            '    <style name="%s">\n' % escxml(t_name)
+            + "      <table "
+            + 'description="%s" ' % escxml(t_style.get_description())
+            + 'width="%d" ' % t_style.get_width()
+            + 'columns="%d"' % t_style.get_columns()
+            + ">\n"
+        )
 
         for col in range(t_style.get_columns()):
             column_width = t_style.get_column_width(col)
             xml_file.write('        <column width="%d" />\n' % column_width)
 
-        xml_file.write('      </table>\n')
-        xml_file.write('    </style>\n')
+        xml_file.write("      </table>\n")
+        xml_file.write("    </style>\n")
 
     def write_cell_style(self, xml_file, sheet, c_name):
-
         cell = sheet.get_cell_style(c_name)
 
         # Write out style definition
         xml_file.write(
-            '    <style name="%s">\n' % escxml(c_name) +
-            '      <cell ' +
-                    'description="%s" ' % escxml(cell.get_description()) +
-                    'lborder="%d" ' % cell.get_left_border() +
-                    'rborder="%d" ' % cell.get_right_border() +
-                    'tborder="%d" ' % cell.get_top_border() +
-                    'bborder="%d" ' % cell.get_bottom_border() +
-                    'pad="%.3f" ' % cell.get_padding() +
-                    '/>\n' +
-            '    </style>\n'
+            '    <style name="%s">\n' % escxml(c_name)
+            + "      <cell "
+            + 'description="%s" ' % escxml(cell.get_description())
+            + 'lborder="%d" ' % cell.get_left_border()
+            + 'rborder="%d" ' % cell.get_right_border()
+            + 'tborder="%d" ' % cell.get_top_border()
+            + 'bborder="%d" ' % cell.get_bottom_border()
+            + 'pad="%.3f" ' % cell.get_padding()
+            + "/>\n"
+            + "    </style>\n"
         )
 
     def write_graphics_style(self, xml_file, sheet, g_name):
-
         draw = sheet.get_draw_style(g_name)
 
         # Write out style definition
         xml_file.write(
-            '    <style name="%s">\n' % escxml(g_name) +
-            '      <draw ' +
-                    'description="%s" ' % escxml(draw.get_description()) +
-                    'para="%s" ' % draw.get_paragraph_style() +
-                    'width="%.3f" ' % draw.get_line_width() +
-                    'style="%d" ' % draw.get_line_style() +
-                    'color="#%02x%02x%02x" ' % draw.get_color() +
-                    'fillcolor="#%02x%02x%02x" ' % draw.get_fill_color() +
-                    'shadow="%d" ' % draw.get_shadow() +
-                    'space="%.3f" ' % draw.get_shadow_space() +
-                    '/>\n' +
-            '    </style>\n'
+            '    <style name="%s">\n' % escxml(g_name)
+            + "      <draw "
+            + 'description="%s" ' % escxml(draw.get_description())
+            + 'para="%s" ' % draw.get_paragraph_style()
+            + 'width="%.3f" ' % draw.get_line_width()
+            + 'style="%d" ' % draw.get_line_style()
+            + 'color="#%02x%02x%02x" ' % draw.get_color()
+            + 'fillcolor="#%02x%02x%02x" ' % draw.get_fill_color()
+            + 'shadow="%d" ' % draw.get_shadow()
+            + 'space="%.3f" ' % draw.get_shadow_space()
+            + "/>\n"
+            + "    </style>\n"
         )
 
     def parse(self):
@@ -284,11 +285,12 @@ class StyleSheetList:
         except (IOError, OSError, SAXParseException):
             pass
 
-#------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------
 #
 # StyleSheet
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 class StyleSheet:
     """
     A collection of named paragraph styles.
@@ -339,10 +341,12 @@ class StyleSheet:
 
     def is_empty(self):
         "Checks if any styles are defined"
-        style_count = len(self.para_styles)  + \
-                      len(self.draw_styles)  + \
-                      len(self.table_styles) + \
-                      len(self.cell_styles)
+        style_count = (
+            len(self.para_styles)
+            + len(self.draw_styles)
+            + len(self.table_styles)
+            + len(self.cell_styles)
+        )
         if style_count > 0:
             return False
         else:
@@ -432,11 +436,12 @@ class StyleSheet:
         "Return the list of cell style names in the StyleSheet"
         return list(self.cell_styles.keys())
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # SheetParser
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class SheetParser(handler.ContentHandler):
     """
     SAX parsing class for the StyleSheetList XML file.
@@ -465,69 +470,68 @@ class SheetParser(handler.ContentHandler):
         """
         if tag == "sheet":
             self.s = StyleSheet(self.sheetlist.map["default"])
-            self.sheet_name = attrs['name']
+            self.sheet_name = attrs["name"]
         elif tag == "font":
             self.f = FontStyle()
-            self.f.set_type_face(int(attrs['face']))
-            self.f.set_size(int(attrs['size']))
-            self.f.set_italic(int(attrs['italic']))
-            self.f.set_bold(int(attrs['bold']))
-            self.f.set_underline(int(attrs['underline']))
-            self.f.set_color(cnv2color(attrs['color']))
+            self.f.set_type_face(int(attrs["face"]))
+            self.f.set_size(int(attrs["size"]))
+            self.f.set_italic(int(attrs["italic"]))
+            self.f.set_bold(int(attrs["bold"]))
+            self.f.set_underline(int(attrs["underline"]))
+            self.f.set_color(cnv2color(attrs["color"]))
         elif tag == "para":
             self.p = ParagraphStyle()
-            if 'description' in attrs:
-                self.p.set_description(attrs['description'])
-            self.p.set_right_margin(float(attrs['rmargin']))
-            self.p.set_left_margin(float(attrs['lmargin']))
-            self.p.set_first_indent(float(attrs['first']))
+            if "description" in attrs:
+                self.p.set_description(attrs["description"])
+            self.p.set_right_margin(float(attrs["rmargin"]))
+            self.p.set_left_margin(float(attrs["lmargin"]))
+            self.p.set_first_indent(float(attrs["first"]))
             try:
                 # This is needed to read older style files
                 # lacking tmargin and bmargin
-                self.p.set_top_margin(float(attrs['tmargin']))
-                self.p.set_bottom_margin(float(attrs['bmargin']))
+                self.p.set_top_margin(float(attrs["tmargin"]))
+                self.p.set_bottom_margin(float(attrs["bmargin"]))
             except KeyError:
                 pass
-            self.p.set_padding(float(attrs['pad']))
-            self.p.set_alignment(int(attrs['align']))
-            self.p.set_right_border(int(attrs['rborder']))
-            self.p.set_header_level(int(attrs['level']))
-            self.p.set_left_border(int(attrs['lborder']))
-            self.p.set_top_border(int(attrs['tborder']))
-            self.p.set_bottom_border(int(attrs['bborder']))
-            self.p.set_background_color(cnv2color(attrs['bgcolor']))
+            self.p.set_padding(float(attrs["pad"]))
+            self.p.set_alignment(int(attrs["align"]))
+            self.p.set_right_border(int(attrs["rborder"]))
+            self.p.set_header_level(int(attrs["level"]))
+            self.p.set_left_border(int(attrs["lborder"]))
+            self.p.set_top_border(int(attrs["tborder"]))
+            self.p.set_bottom_border(int(attrs["bborder"]))
+            self.p.set_background_color(cnv2color(attrs["bgcolor"]))
             self.p.set_font(self.f)
         elif tag == "style":
-            self.style_name = attrs['name']
+            self.style_name = attrs["name"]
         elif tag == "table":
             self.t = TableStyle()
-            if 'description' in attrs:
-                self.t.set_description(attrs['description'])
-            self.t.set_width(int(attrs['width']))
-            self.t.set_columns(int(attrs['columns']))
+            if "description" in attrs:
+                self.t.set_description(attrs["description"])
+            self.t.set_width(int(attrs["width"]))
+            self.t.set_columns(int(attrs["columns"]))
             self.column_widths = []
         elif tag == "column":
-            self.column_widths.append(int(attrs['width']))
+            self.column_widths.append(int(attrs["width"]))
         elif tag == "cell":
             self.c = TableCellStyle()
-            if 'description' in attrs:
-                self.c.set_description(attrs['description'])
-            self.c.set_left_border(int(attrs['lborder']))
-            self.c.set_right_border(int(attrs['rborder']))
-            self.c.set_top_border(int(attrs['tborder']))
-            self.c.set_bottom_border(int(attrs['bborder']))
-            self.c.set_padding(float(attrs['pad']))
+            if "description" in attrs:
+                self.c.set_description(attrs["description"])
+            self.c.set_left_border(int(attrs["lborder"]))
+            self.c.set_right_border(int(attrs["rborder"]))
+            self.c.set_top_border(int(attrs["tborder"]))
+            self.c.set_bottom_border(int(attrs["bborder"]))
+            self.c.set_padding(float(attrs["pad"]))
         elif tag == "draw":
             self.g = GraphicsStyle()
-            if 'description' in attrs:
-                self.g.set_description(attrs['description'])
-            self.g.set_paragraph_style(attrs['para'])
-            self.g.set_line_width(float(attrs['width']))
-            self.g.set_line_style(int(attrs['style']))
-            self.g.set_color(cnv2color(attrs['color']))
-            self.g.set_fill_color(cnv2color(attrs['fillcolor']))
-            self.g.set_shadow(int(attrs['shadow']),
-                              float(attrs['space']))
+            if "description" in attrs:
+                self.g.set_description(attrs["description"])
+            self.g.set_paragraph_style(attrs["para"])
+            self.g.set_line_width(float(attrs["width"]))
+            self.g.set_line_style(int(attrs["style"]))
+            self.g.set_color(cnv2color(attrs["color"]))
+            self.g.set_fill_color(cnv2color(attrs["fillcolor"]))
+            self.g.set_shadow(int(attrs["shadow"]), float(attrs["space"]))
 
     def endElement(self, tag):
         "Overridden class that handles the end of a XML element"
