@@ -22,35 +22,43 @@
 
 "Report Generation Framework"
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # standard python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ...const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 import os
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Constants
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 # Report categories
-from .. import (CATEGORY_TEXT, CATEGORY_DRAW, CATEGORY_CODE, CATEGORY_WEB,
-                CATEGORY_BOOK, CATEGORY_GRAPHVIZ, CATEGORY_TREE)
+from .. import (
+    CATEGORY_TEXT,
+    CATEGORY_DRAW,
+    CATEGORY_CODE,
+    CATEGORY_WEB,
+    CATEGORY_BOOK,
+    CATEGORY_GRAPHVIZ,
+    CATEGORY_TREE,
+)
 
 standalone_categories = {
-    CATEGORY_TEXT     : ("RepText", _("Text Reports")),
-    CATEGORY_DRAW     : ("RepGraph", _("Graphical Reports")),
-    CATEGORY_CODE     : ("RepCode", _("Code Generators")),
-    CATEGORY_WEB      : ("RepWeb", _("Web Pages")),
-    CATEGORY_BOOK     : ("RepBook", _("Books")),
-    CATEGORY_GRAPHVIZ : ("Graphs", _("Graphs")),
-    CATEGORY_TREE    : ("Trees", _("Trees")),
+    CATEGORY_TEXT: ("RepText", _("Text Reports")),
+    CATEGORY_DRAW: ("RepGraph", _("Graphical Reports")),
+    CATEGORY_CODE: ("RepCode", _("Code Generators")),
+    CATEGORY_WEB: ("RepWeb", _("Web Pages")),
+    CATEGORY_BOOK: ("RepBook", _("Books")),
+    CATEGORY_GRAPHVIZ: ("Graphs", _("Graphs")),
+    CATEGORY_TREE: ("Trees", _("Trees")),
 }
 book_categories = {
-    CATEGORY_TEXT : _("Text"),
-    CATEGORY_DRAW : _("Graphics"),
+    CATEGORY_TEXT: _("Text"),
+    CATEGORY_DRAW: _("Graphics"),
 }
