@@ -23,38 +23,41 @@ from gramps.gen.const import GRAMPS_LOCALE as glocale
 GtkWidget showing a box for interactive-search in Gtk.TreeView
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import logging
+
 _LOG = logging.getLogger(".widgets.interactivesearch")
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # GTK modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gi.repository import Gtk, Gdk, GLib
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
-from ..utils import match_primary_mask
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
+from ..utils import match_primary_mask, get_display_size
+
+# -------------------------------------------------------------------------
 #
 # InteractiveSearchBox class
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class InteractiveSearchBox:
     """
     Mainly adapted from gtktreeview.c
     """
+
     _SEARCH_DIALOG_TIMEOUT = 5000
     _SEARCH_DIALOG_LAUNCH_TIMEOUT = 150
 
@@ -85,13 +88,11 @@ class InteractiveSearchBox:
         # Make a copy of the current text
         old_text = self._search_entry.get_text()
 
-        popup_menu_id = self._search_entry.connect("popup-menu",
-                                                   lambda x: True)
+        popup_menu_id = self._search_entry.connect("popup-menu", lambda x: True)
 
         # Move the entry off screen
-        screen = self._treeview.get_screen()
-        self._search_window.move(screen.get_width() + 1,
-                                 screen.get_height() + 1)
+        width, height = get_display_size(self._treeview)
+        self._search_window.move(width + 1, height + 1)
         self._search_window.show()
 
         # Send the event to the window.  If the preedit_changed signal is
@@ -106,17 +107,17 @@ class InteractiveSearchBox:
         self._search_entry.disconnect(popup_menu_id)
 
         # Intercept CTRL+F keybinding because Gtk do not allow to _replace_ it.
-        if (match_primary_mask(event.state)
-                and event.keyval in [Gdk.KEY_f, Gdk.KEY_F]):
+        if match_primary_mask(event.state) and event.keyval in [Gdk.KEY_f, Gdk.KEY_F]:
             self.__imcontext_changed = True
             # self.real_start_interactive_search(event.get_device(), True)
 
         # We check to make sure that the entry tried to handle the text,
         # and that the text has changed.
         new_text = self._search_entry.get_text()
-        text_modified = (old_text != new_text)
-        if (self.__imcontext_changed or  # we're in a preedit
-                (retval and text_modified)):  # ...or the text was modified
+        text_modified = old_text != new_text
+        if self.__imcontext_changed or (  # we're in a preedit
+            retval and text_modified
+        ):  # ...or the text was modified
             self.real_start_interactive_search(event.get_device(), False)
             self._treeview.grab_focus()
             return True
@@ -126,33 +127,29 @@ class InteractiveSearchBox:
 
     def _preedit_changed(self, im_context, tree_view):
         self.__imcontext_changed = 1
-        if(self._entry_flush_timeout):
+        if self._entry_flush_timeout:
             GLib.source_remove(self._entry_flush_timeout)
             self._entry_flush_timeout = GLib.timeout_add(
-                self._SEARCH_DIALOG_TIMEOUT, self.cb_entry_flush_timeout)
+                self._SEARCH_DIALOG_TIMEOUT, self.cb_entry_flush_timeout
+            )
 
     def ensure_interactive_directory(self):
         toplevel = self._treeview.get_toplevel()
-        screen = self._treeview.get_screen()
         if self._search_window:
             if toplevel.has_group():
                 toplevel.get_group().add_window(self._search_window)
             elif self._search_window.has_group():
-                self._search_window.get_group().remove_window(
-                    self._search_window)
-            self._search_window.set_screen(screen)
+                self._search_window.get_group().remove_window(self._search_window)
             return
 
         self._search_window = Gtk.Window(type=Gtk.WindowType.POPUP)
-        self._search_window.set_screen(screen)
         if toplevel.has_group():
             toplevel.get_group().add_window(self._search_window)
         self._search_window.set_type_hint(Gdk.WindowTypeHint.UTILITY)
         self._search_window.set_modal(True)
         self._search_window.connect("delete-event", self._delete_event)
         self._search_window.connect("key-press-event", self._key_press_event)
-        self._search_window.connect("button-press-event",
-                                    self._button_press_event)
+        self._search_window.connect("button-press-event", self._button_press_event)
         self._search_window.connect("scroll-event", self._scroll_event)
         frame = Gtk.Frame()
         frame.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
@@ -180,7 +177,7 @@ class InteractiveSearchBox:
         the user started this by typing the start_interactive_search
         keybinding. Otherwise, it came from just typing
         """
-        if (self._search_window.get_visible()):
+        if self._search_window.get_visible():
             return True
         self.ensure_interactive_directory()
         if keybinding:
@@ -188,8 +185,9 @@ class InteractiveSearchBox:
         self._position_func()
         self._search_window.show()
         if self._search_entry_changed_id == 0:
-            self._search_entry_changed_id = \
-                self._search_entry.connect("changed", self.delayed_changed)
+            self._search_entry_changed_id = self._search_entry.connect(
+                "changed", self.delayed_changed
+            )
 
         # Grab focus without selecting all the text
         self._search_entry.grab_focus()
@@ -199,7 +197,7 @@ class InteractiveSearchBox:
         event.type = Gdk.EventType.FOCUS_CHANGE
         event.focus_change.in_ = True
         event.focus_change.window = self._search_window.get_window()
-        self._search_entry.emit('focus-in-event', event)
+        self._search_entry.emit("focus-in-event", event)
         # search first matching iter
         self.delayed_changed(self._search_entry)
         # uncomment when deleting delayed_changed
@@ -227,7 +225,8 @@ class InteractiveSearchBox:
         if self._entry_launchsearch_timeout:
             GLib.source_remove(self._entry_launchsearch_timeout)
         self._entry_launchsearch_timeout = GLib.timeout_add(
-            self._SEARCH_DIALOG_LAUNCH_TIMEOUT, self.search_init)
+            self._SEARCH_DIALOG_LAUNCH_TIMEOUT, self.search_init
+        )
 
     def search_init(self):
         """
@@ -259,7 +258,8 @@ class InteractiveSearchBox:
         if self._entry_flush_timeout:
             GLib.source_remove(self._entry_flush_timeout)
         self._entry_flush_timeout = GLib.timeout_add(
-            self._SEARCH_DIALOG_TIMEOUT, self.cb_entry_flush_timeout)
+            self._SEARCH_DIALOG_TIMEOUT, self.cb_entry_flush_timeout
+        )
 
     def _move(self, up=False):
         text = self._search_entry.get_text()
@@ -278,15 +278,15 @@ class InteractiveSearchBox:
         # search
         start_count = self.__selected_search_result + (-1 if up else 1)
         start_iter = model.get_iter_first()
-        found_iter = self.search_iter(selection, start_iter, text, 0,
-                                      start_count)
+        found_iter = self.search_iter(selection, start_iter, text, 0, start_count)
         if found_iter:
-            self.__selected_search_result += (-1 if up else 1)
+            self.__selected_search_result += -1 if up else 1
             return True
         else:
             # Return to old iter
-            self.search_iter(selection, start_iter, text, 0,
-                             self.__selected_search_result)
+            self.search_iter(
+                selection, start_iter, text, 0, self.__selected_search_result
+            )
             return False
         # renew flush timeout
         self._renew_flush_timeout()
@@ -296,13 +296,14 @@ class InteractiveSearchBox:
         self.cb_entry_flush_timeout()
         # If we have a row selected and it's the cursor row, we activate
         # the row XXX
-#         if self._cursor_node and \
-#             self._cursor_node.set_flag(Gtk.GTK_RBNODE_IS_SELECTED):
-#             path = _gtk_tree_path_new_from_rbtree(
-#                            tree_view->priv->cursor_tree,
-#                            tree_view->priv->cursor_node)
-#             gtk_tree_view_row_activated(tree_view, path,
-#                                         tree_view->priv->focus_column)
+
+    #         if self._cursor_node and \
+    #             self._cursor_node.set_flag(Gtk.GTK_RBNODE_IS_SELECTED):
+    #             path = _gtk_tree_path_new_from_rbtree(
+    #                            tree_view->priv->cursor_tree,
+    #                            tree_view->priv->cursor_node)
+    #             gtk_tree_view_row_activated(tree_view, path,
+    #                                         tree_view->priv->focus_column)
 
     def _button_press_event(self, obj, event):
         if not obj:
@@ -320,7 +321,8 @@ class InteractiveSearchBox:
 
     def _enable_popdown(self, obj):
         self._timeout_enable_popdown = GLib.timeout_add(
-            self._SEARCH_DIALOG_TIMEOUT, self._real_search_enable_popdown)
+            self._SEARCH_DIALOG_TIMEOUT, self._real_search_enable_popdown
+        )
 
     def _real_search_enable_popdown(self):
         self.__disable_popdown = 0
@@ -332,20 +334,22 @@ class InteractiveSearchBox:
 
     def _scroll_event(self, obj, event):
         retval = False
-        if (event.direction == Gdk.ScrollDirection.UP):
+        if event.direction == Gdk.ScrollDirection.UP:
             self._move(True)
             retval = True
-        elif (event.direction == Gdk.ScrollDirection.DOWN):
+        elif event.direction == Gdk.ScrollDirection.DOWN:
             self._move(False)
             retval = True
         if retval:
             self._renew_flush_timeout()
 
     def _key_cancels_search(self, keyval):
-        return keyval in [Gdk.KEY_Escape,
-                          Gdk.KEY_Tab,
-                          Gdk.KEY_KP_Tab,
-                          Gdk.KEY_ISO_Left_Tab]
+        return keyval in [
+            Gdk.KEY_Escape,
+            Gdk.KEY_Tab,
+            Gdk.KEY_KP_Tab,
+            Gdk.KEY_ISO_Left_Tab,
+        ]
 
     def _key_press_event(self, widget, event):
         retval = False
@@ -354,30 +358,35 @@ class InteractiveSearchBox:
             self.cb_entry_flush_timeout()
             return True
         # Launch search
-        if (event.keyval in [Gdk.KEY_Return, Gdk.KEY_KP_Enter]):
+        if event.keyval in [Gdk.KEY_Return, Gdk.KEY_KP_Enter]:
             if self._entry_launchsearch_timeout:
                 GLib.source_remove(self._entry_launchsearch_timeout)
                 self._entry_launchsearch_timeout = 0
             self.search_init()
             retval = True
 
-        default_accel = widget.get_modifier_mask(
-            Gdk.ModifierIntent.PRIMARY_ACCELERATOR)
+        default_accel = widget.get_modifier_mask(Gdk.ModifierIntent.PRIMARY_ACCELERATOR)
         # select previous matching iter
-        if ((event.keyval in [Gdk.KEY_Up, Gdk.KEY_KP_Up]) or
-            (((event.state & (default_accel | Gdk.ModifierType.SHIFT_MASK))
-                == (default_accel | Gdk.ModifierType.SHIFT_MASK))
-                and (event.keyval in [Gdk.KEY_g, Gdk.KEY_G]))):
-            if(not self._move(True)):
+        if (event.keyval in [Gdk.KEY_Up, Gdk.KEY_KP_Up]) or (
+            (
+                (event.state & (default_accel | Gdk.ModifierType.SHIFT_MASK))
+                == (default_accel | Gdk.ModifierType.SHIFT_MASK)
+            )
+            and (event.keyval in [Gdk.KEY_g, Gdk.KEY_G])
+        ):
+            if not self._move(True):
                 widget.error_bell()
             retval = True
 
         # select next matching iter
-        if ((event.keyval in [Gdk.KEY_Down, Gdk.KEY_KP_Down]) or
-            (((event.state & (default_accel | Gdk.ModifierType.SHIFT_MASK))
-                == (default_accel))
-                and (event.keyval in [Gdk.KEY_g, Gdk.KEY_G]))):
-            if(not self._move(False)):
+        if (event.keyval in [Gdk.KEY_Down, Gdk.KEY_KP_Down]) or (
+            (
+                (event.state & (default_accel | Gdk.ModifierType.SHIFT_MASK))
+                == (default_accel)
+            )
+            and (event.keyval in [Gdk.KEY_g, Gdk.KEY_G])
+        ):
+            if not self._move(False):
                 widget.error_bell()
             retval = True
 
@@ -400,18 +409,15 @@ class InteractiveSearchBox:
             self._entry_launchsearch_timeout = 0
         if self._search_window.get_visible():
             # send focus-in event
-            self._search_entry.emit('focus-out-event', event)
+            self._search_entry.emit("focus-out-event", event)
             self._search_window.hide()
             self._search_entry.set_text("")
-            self._treeview.emit('focus-in-event', event)
+            self._treeview.emit("focus-in-event", event)
         self.__selected_search_result = 0
 
     def _position_func(self, userdata=None):
         tree_window = self._treeview.get_window()
-        screen = self._treeview.get_screen()
-
-        monitor_num = screen.get_monitor_at_window(tree_window)
-        monitor = screen.get_monitor_workarea(monitor_num)
+        s_width, s_height = get_display_size(tree_window)
 
         self._search_window.realize()
         ret, tree_x, tree_y = tree_window.get_origin()
@@ -419,16 +425,16 @@ class InteractiveSearchBox:
         tree_height = tree_window.get_height()
         _, requisition = self._search_window.get_preferred_size()
 
-        if tree_x + tree_width > screen.get_width():
-            x = screen.get_width() - requisition.width
+        if tree_x + tree_width > s_width:
+            x = s_width - requisition.width
         elif tree_x + tree_width - requisition.width < 0:
             x = 0
         else:
             x = tree_x + tree_width - requisition.width
 
-        if tree_y + tree_height + requisition.height > screen.get_height():
-            y = screen.get_height() - requisition.height
-        elif(tree_y + tree_height < 0):  # isn't really possible ...
+        if tree_y + tree_height + requisition.height > s_height:
+            y = s_height - requisition.height
+        elif tree_y + tree_height < 0:  # isn't really possible ...
             y = 0
         else:
             y = tree_y + tree_height
@@ -445,12 +451,11 @@ class InteractiveSearchBox:
         search_column = self._treeview.get_search_column()
         is_tree = not (model.get_flags() & Gtk.TreeModelFlags.LIST_ONLY)
         while True:
-            if not cur_iter:    # can happen on empty list
+            if not cur_iter:  # can happen on empty list
                 return False
-            if (self.search_equal_func(model, search_column,
-                                       text, cur_iter)):
+            if self.search_equal_func(model, search_column, text, cur_iter):
                 count += 1
-                if (count == n):
+                if count == n:
                     found_path = model.get_path(cur_iter)
                     self._treeview.expand_to_path(found_path)
                     self._treeview.scroll_to_cell(found_path, None, 1, 0.5, 0)
@@ -469,7 +474,7 @@ class InteractiveSearchBox:
                         done = True
                     else:
                         cur_iter = model.iter_parent(cur_iter)
-                        if(not cur_iter):
+                        if not cur_iter:
                             # we've run out of tree, done with this func
                             return False
                     if done:
@@ -485,15 +490,15 @@ class InteractiveSearchBox:
 
     def search_iter(self, selection, cur_iter, text, count, n):
         model = self._treeview.get_model()
-        is_listonly = (model.get_flags() & Gtk.TreeModelFlags.LIST_ONLY)
+        is_listonly = model.get_flags() & Gtk.TreeModelFlags.LIST_ONLY
         if is_listonly and hasattr(model, "node_map"):
-            return self.search_iter_sorted_column_flat(selection, cur_iter,
-                                                       text, count, n)
+            return self.search_iter_sorted_column_flat(
+                selection, cur_iter, text, count, n
+            )
         else:
             return self.search_iter_slow(selection, cur_iter, text, count, n)
 
-    def search_iter_sorted_column_flat(self, selection, cur_iter, text,
-                                       count, n):
+    def search_iter_sorted_column_flat(self, selection, cur_iter, text, count, n):
         """
         Search among the currently set search-column for a cell starting with
         text
@@ -508,6 +513,7 @@ class InteractiveSearchBox:
         # If there is a sort_key index, let's use it
         if not is_tree and hasattr(model, "node_map"):
             import bisect
+
             index2hndl = model.node_map._index2hndl
 
             # create lookup key from the appropriate sort_func
