@@ -29,94 +29,99 @@
 Report output generator for html documents, based on Html and HtmlBackend
 """
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
-# python modules 
+# Python modules
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 import os
 import shutil
-import time
+import logging
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
-# GRAMPS modules 
+# Gramps modules
 #
-#------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
+# ------------------------------------------------------------------------
 from gramps.gen.utils.image import resize_to_jpeg
 from gramps.gen.const import DATA_DIR, IMAGE_DIR, PROGRAM_NAME, URL_HOMEPAGE
+from gramps.gen.errors import ReportError
 from gramps.version import VERSION
-from gramps.gen.plug.docgen import BaseDoc, TextDoc, FONT_SANS_SERIF, URL_PATTERN
+from gramps.gen.plug.docgen import BaseDoc, TextDoc, URL_PATTERN
 from gramps.plugins.lib.libhtmlbackend import HtmlBackend, process_spaces
 from gramps.plugins.lib.libhtml import Html
+from gramps.gen.const import GRAMPS_LOCALE as glocale
 
-#------------------------------------------------------------------------
+_ = glocale.translation.gettext
+
+# ------------------------------------------------------------------------
 #
 # Set up logging
 #
-#------------------------------------------------------------------------
-import logging
+# ------------------------------------------------------------------------
 LOG = logging.getLogger(".htmldoc")
 
-_TEXTDOCSCREEN = 'grampstextdoc.css'
-_HTMLSCREEN = 'grampshtml.css'
+_TEXTDOCSCREEN = "grampstextdoc.css"
+_HTMLSCREEN = "grampshtml.css"
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
 # Set up to make links clickable
 #
-#------------------------------------------------------------------------
-_CLICKABLE = r'''<a href="\1">\1</a>'''
+# ------------------------------------------------------------------------
+_CLICKABLE = r"""<a href="\1">\1</a>"""
 
-#------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------
 #
 # HtmlDoc
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 class HtmlDoc(BaseDoc, TextDoc):
-    """Implementation of the BaseDoc and TextDoc gen.plug.docgen api for the 
+    """Implementation of the BaseDoc and TextDoc gen.plug.docgen api for the
     creation of Html files. This is achieved by writing on a HtmlBackend
     object
-    
+
     div id's defined here:
         id="grampstextdoc" : the entire text report
         id="grampsheading" : a small defined heading, but not h1 to h6 !
-        id="grampsstylednote" : start of part with a styled note, divided in 
+        id="grampsstylednote" : start of part with a styled note, divided in
                                 paragraphs
-        id="grampsnote" : start of part with a note. This id is normally not 
+        id="grampsnote" : start of part with a note. This id is normally not
                           used
-    
+
     The styles as defined in the stylesheed of the textdoc, will be converted
-    to css class. Color is removed to avoid conflicts with the css. Also 
+    to css class. Color is removed to avoid conflicts with the css. Also
     Fontface is removed. Size, italic, bold, margins, borders are retained
     """
 
-    def __init__(self, styles, paper_style):
-        BaseDoc.__init__(self, styles, None)
-        self.style_declaration = ''
+    def __init__(self, styles, paper_style, uistate=None):
+        BaseDoc.__init__(self, styles, None, uistate=uistate)
+        self.style_declaration = ""
         self.htmllist = []
         self._backend = None
-        self.css_filename = ''
+        self.css_filename = ""
         self.warn_dir = True
         self._col = 0
         self._tbl = None
         self._empty = 1
-        self.title = ''
+        self.title = ""
         self.__title_written = -1  # -1 = not written, 0 = writing, 1 = written
-        self.__link_attrs = {}     # additional link attrs, eg {"style": "...", "class": "..."}
-        self.use_table_headers = False # th, td
+        self.__link_attrs = (
+            {}
+        )  # additional link attrs, eg {"style": "...", "class": "..."}
+        self.use_table_headers = False  # th, td
+        self.first_row = True
 
     def set_css_filename(self, css_filename):
         """
-        Set the css file to use. The path must be included. 
+        Set the css file to use. The path must be included.
         Note: DocReportDialog sets this for html doc
         """
         if css_filename and os.path.basename(css_filename):
             self.css_filename = css_filename
         else:
-            self.css_filename = ''
+            self.css_filename = ""
 
     def open(self, filename):
         """
@@ -125,9 +130,9 @@ class HtmlDoc(BaseDoc, TextDoc):
         self._backend = HtmlBackend(filename)
         self._backend.open()
         self.htmllist += [self._backend.html_body]
-        #start a gramps report
-        self.htmllist += [Html('div', id="grampstextdoc")]
-        
+        # start a gramps report
+        self.htmllist += [Html("div", id="grampstextdoc")]
+
         self.build_header()
 
     def build_header(self):
@@ -136,28 +141,43 @@ class HtmlDoc(BaseDoc, TextDoc):
         """
         # add additional meta tags and stylesheet links to head section
         # create additional meta tags
-        _meta1 = 'name="generator" content="%s %s %s"' % (PROGRAM_NAME,
-                    VERSION, URL_HOMEPAGE)
-        meta = Html('meta', attr = _meta1) 
-        
-        #set styles of the report as inline css
+        _meta1 = 'name="generator" content="%s %s %s"' % (
+            PROGRAM_NAME,
+            VERSION,
+            URL_HOMEPAGE,
+        )
+        meta = Html("meta", attr=_meta1)
+
+        # set styles of the report as inline css
         self.build_style_declaration()
-        
-        
-        # GRAMPS favicon en css
-        fname1 = '/'.join([self._backend.datadir(), 'favicon.ico'])
-        fname2 = '/'.join([self._backend.datadir(), _TEXTDOCSCREEN])
-        fname3 = '/'.join([self._backend.datadir(), _HTMLSCREEN])
-        
-        # links for GRAMPS favicon and stylesheets
-        links = Html('link', rel='shortcut icon', href=fname1,
-                        type='image/x-icon') + (
-                Html('link', rel='stylesheet', href=fname2, type='text/css',
-                        media='screen', indent=False),)
+
+        # Gramps favicon en css
+        fname1 = "/".join([self._backend.datadir(), "favicon.ico"])
+        fname2 = "/".join([self._backend.datadir(), _TEXTDOCSCREEN])
+        fname3 = "/".join([self._backend.datadir(), _HTMLSCREEN])
+
+        # links for Gramps favicon and stylesheets
+        links = Html("link", rel="shortcut icon", href=fname1, type="image/x-icon") + (
+            Html(
+                "link",
+                rel="stylesheet",
+                href=fname2,
+                type="text/css",
+                media="screen",
+                indent=False,
+            ),
+        )
         if self.css_filename:
-            links += (Html('link', rel='stylesheet', href=fname3, 
-                      type='text/css', media='screen', indent=False),
-                )
+            links += (
+                Html(
+                    "link",
+                    rel="stylesheet",
+                    href=fname3,
+                    type="text/css",
+                    media="screen",
+                    indent=False,
+                ),
+            )
         self._backend.html_header += (meta, links)
 
     def build_style_declaration(self, id="grampstextdoc"):
@@ -165,34 +185,34 @@ class HtmlDoc(BaseDoc, TextDoc):
         Convert the styles of the report into inline css for the html doc
         """
         styles = self.get_style_sheet()
-        
+
         text = []
 
         for sname in sorted(styles.get_cell_style_names()):
             style = styles.get_cell_style(sname)
-            pad = "%.3fcm"  % style.get_padding()
-            top = bottom = left = right = 'none'
+            pad = "%.3fcm" % style.get_padding()
+            top = bottom = left = right = "none"
             if style.get_top_border():
-                top = 'thin solid #000000'
+                top = "thin solid #000000"
             if style.get_bottom_border():
-                bottom = 'thin solid #000000'
+                bottom = "thin solid #000000"
             if style.get_left_border():
-                left = 'thin solid #000000'
+                left = "thin solid #000000"
             if style.get_right_border():
-                right = 'thin solid #000000'
-            text.append('#%s .%s {\n'
-                        '\tpadding: %s %s %s %s;\n'
-                        '\tborder-top:%s; border-bottom:%s;\n' 
-                        '\tborder-left:%s; border-right:%s;\n}' 
-                    % (id, sname, pad, pad, pad, pad, top, bottom, 
-                       left, right))
-
+                right = "thin solid #000000"
+            text.append(
+                "#%s .%s {\n"
+                "\tpadding: %s %s %s %s;\n"
+                "\tborder-top:%s; border-bottom:%s;\n"
+                "\tborder-left:%s; border-right:%s;\n}"
+                % (id, sname, pad, pad, pad, pad, top, bottom, left, right)
+            )
 
         for style_name in sorted(styles.get_paragraph_style_names()):
             style = styles.get_paragraph_style(style_name)
             font = style.get_font()
             font_size = font.get_size()
-            #font_color = '#%02x%02x%02x' % font.get_color()
+            # font_color = '#%02x%02x%02x' % font.get_color()
             align = style.get_alignment_text()
             text_indent = "%.2f" % style.get_first_indent()
             right_margin = "%.2f" % style.get_right_margin()
@@ -200,66 +220,79 @@ class HtmlDoc(BaseDoc, TextDoc):
             top_margin = "%.2f" % style.get_top_margin()
             bottom_margin = "%.2f" % style.get_bottom_margin()
 
-            top = bottom = left = right = 'none'
+            top = bottom = left = right = "none"
             if style.get_top_border():
-                top = 'thin solid #000000'
+                top = "thin solid #000000"
             if style.get_bottom_border():
-                bottom = 'thin solid #000000'
+                bottom = "thin solid #000000"
             if style.get_left_border():
-                left = 'thin solid #000000'
+                left = "thin solid #000000"
             if style.get_right_border():
-                right = 'thin solid #000000'
+                right = "thin solid #000000"
 
-            italic = bold = ''
+            italic = bold = ""
             if font.get_italic():
-                italic = 'font-style:italic; '
+                italic = "font-style:italic; "
             if font.get_bold():
-                bold = 'font-weight:bold; '
-            #if font.get_type_face() == FONT_SANS_SERIF:
+                bold = "font-weight:bold; "
+            # if font.get_type_face() == FONT_SANS_SERIF:
             #    family = '"Helvetica","Arial","sans-serif"'
-            #else:
+            # else:
             #    family = '"Times New Roman","Times","serif"'
-            # do not allow color, set in base css ! 
-            #    so no : 'color: %s' % font_color 
+            # do not allow color, set in base css !
+            #    so no : 'color: %s' % font_color
             #    so no : 'font-family:%s;' % family
-            text.append('#%s .%s {\n'
-                        '\tfont-size: %dpt;\n' 
-                        '\ttext-align: %s; text-indent: %scm;\n' 
-                        '\tmargin-right: %scm; margin-left: %scm;\n' 
-                        '\tmargin-top: %scm; margin-bottom: %scm;\n' 
-                        '\tborder-top:%s; border-bottom:%s;\n' 
-                        '\tborder-left:%s; border-right:%s;\n' 
-                        '\t%s%s\n}' 
-                        % (id, style_name, font_size, 
-                           align, text_indent,
-                           right_margin, left_margin,
-                           top_margin, bottom_margin,
-                           top, bottom, left, right,
-                           italic, bold))
+            text.append(
+                "#%s .%s {\n"
+                "\tfont-size: %dpt;\n"
+                "\ttext-align: %s; text-indent: %scm;\n"
+                "\tmargin-right: %scm; margin-left: %scm;\n"
+                "\tmargin-top: %scm; margin-bottom: %scm;\n"
+                "\tborder-top:%s; border-bottom:%s;\n"
+                "\tborder-left:%s; border-right:%s;\n"
+                "\t%s%s\n}"
+                % (
+                    id,
+                    style_name,
+                    font_size,
+                    align,
+                    text_indent,
+                    right_margin,
+                    left_margin,
+                    top_margin,
+                    bottom_margin,
+                    top,
+                    bottom,
+                    left,
+                    right,
+                    italic,
+                    bold,
+                )
+            )
 
-        self.style_declaration = '\n'.join(text)
+        self.style_declaration = "\n".join(text)
 
     def close(self):
         """
         Overwrite base method
         """
-        while len(self.htmllist)>1 :
+        while len(self.htmllist) > 1:
             self.__reduce_list()
-        #now write the actual file
+        # now write the actual file
         self._backend.close()
         self.write_support_files()
 
-    def copy_file(self, from_fname, to_fname, to_dir=''):
+    def copy_file(self, from_fname, to_fname, to_dir=""):
         """
-        Copy a file from a source to a (report) destination.
-        If to_dir is not present, then the destination directory will be created.
+        Copy a file from a source to a (report) destination. If to_dir is not
+        present, then the destination directory will be created.
 
         Normally 'to_fname' will be just a filename, without directory path.
 
         'to_dir' is the relative path name in the destination root. It will
         be prepended before 'to_fname'.
         """
-        #build absolute path
+        # build absolute path
         dest = os.path.join(self._backend.datadirfull(), to_dir, to_fname)
 
         destdir = os.path.dirname(dest)
@@ -269,68 +302,72 @@ class HtmlDoc(BaseDoc, TextDoc):
         if from_fname != dest:
             shutil.copyfile(from_fname, dest)
         elif self.warn_dir:
-            from gramps.gui.dialog import WarningDialog
-            WarningDialog(
-                _("Possible destination error") + "\n" +
-                _("You appear to have set your target directory "
-                  "to a directory used for data storage. This "
-                  "could create problems with file management. "
-                  "It is recommended that you consider using "
-                  "a different directory to store your generated "
-                  "web pages."))
+            raise ReportError(
+                _("Possible destination error"),
+                _(
+                    "You appear to have set your target directory "
+                    "to a directory used for data storage. This "
+                    "could create problems with file management. "
+                    "It is recommended that you consider using "
+                    "a different directory to store your generated "
+                    "web pages."
+                ),
+            )
             self.warn_dir = False
-    
+
     def write_support_files(self):
         """
         Copy support files to the datadir that needs to hold them
         """
-        #css of textdoc styles
-        tdfile = open(os.path.join(self._backend.datadirfull(), 
-                      _TEXTDOCSCREEN), 'w')
-        tdfile.write(self.style_declaration)
-        tdfile.close()
-        #css file
+        # css of textdoc styles
+        with open(
+            os.path.join(self._backend.datadirfull(), _TEXTDOCSCREEN), "w"
+        ) as tdfile:
+            tdfile.write(self.style_declaration)
+        # css file
         if self.css_filename:
-            #we do an extra check in case file does not exist, eg cli call
+            # we do an extra check in case file does not exist, eg cli call
             fullpath = os.path.join(DATA_DIR, self.css_filename)
             if os.path.exists(fullpath):
                 self.copy_file(fullpath, _HTMLSCREEN)
-        #favicon
-        self.copy_file(os.path.join(IMAGE_DIR, 'webstuff', 'favicon.ico'), 
-                        'favicon.ico')
+        # favicon
+        self.copy_file(
+            os.path.join(IMAGE_DIR, "webstuff", "favicon.ico"), "favicon.ico"
+        )
 
     def __reduce_list(self):
         """
-        Takes the internal list of html objects, and adds the last to the 
+        Takes the internal list of html objects, and adds the last to the
         previous. This closes the upper tag
         """
         self.htmllist[-2] += self.htmllist[-1]
         self.htmllist.pop()
-    
+
     def __write_text(self, text, mark=None, markup=False, links=False):
         """
         @param text: text to write.
         @param mark:  IndexMark to use for indexing (not supported)
-        @param markup: True if text already contains markup info. 
+        @param markup: True if text already contains markup info.
                        Then text will no longer be escaped
         @param links: make URLs clickable if True
         """
-        if not markup:            
+        if not markup:
             text = self._backend.ESCAPE_FUNC()(text)
-        if self.__title_written == 0 :
+        if self.__title_written == 0:
             self.title += text
-        if links == True:
+        if links is True:
             import re
+
             text = re.sub(URL_PATTERN, _CLICKABLE, text)
         self.htmllist[-1] += text
-    
+
     def __empty_char(self):
         """
-        Output a non breaking whitespace so as to have browser behave ok on 
+        Output a non breaking whitespace so as to have browser behave ok on
         empty content
         """
-        self.__write_text('&nbsp;', markup=True)
-    
+        self.__write_text("&nbsp;", markup=True)
+
     def write_text(self, text, mark=None, links=False):
         """
         Overwrite base method
@@ -339,13 +376,26 @@ class HtmlDoc(BaseDoc, TextDoc):
             self._empty = 0
         self.__write_text(text, mark, links=links)
 
+    def write_markup(self, text, s_tags, mark=None):
+        """
+        Overwrite base method
+        Writes the text in the current paragraph.  Should only be used after a
+        start_paragraph and before an end_paragraph.
+
+        @param text: text to write. The text is assumed to be _not_ escaped
+        @param s_tags:  assumed to be list of styledtexttags to apply to the
+                        text
+        @param mark:  IndexMark to use for indexing
+        """
+        markuptext = self._backend.add_markup_from_styled(text, s_tags)
+        self.__write_text(markuptext, mark=mark, markup=True)
+
     def write_title(self):
         """
         Add title field to header
         """
-        self._backend.html_header += Html('title', self.title, 
-                                          inline=True)
-        
+        self._backend.html_header += Html("title", self.title, inline=True)
+
     def start_table(self, name, style):
         """
         Overwrite base method
@@ -353,8 +403,9 @@ class HtmlDoc(BaseDoc, TextDoc):
         self.first_row = True
         styles = self.get_style_sheet()
         self._tbl = styles.get_table_style(style)
-        self.htmllist += [Html('table', width=str(self._tbl.get_width())+'%',
-                                cellspacing='0')]
+        self.htmllist += [
+            Html("table", width=str(self._tbl.get_width()) + "%", cellspacing="0")
+        ]
 
     def end_table(self):
         """
@@ -366,7 +417,7 @@ class HtmlDoc(BaseDoc, TextDoc):
         """
         Overwrite base method
         """
-        self.htmllist += [Html('tr')]
+        self.htmllist += [Html("tr")]
         self._col = 0
 
     def end_row(self):
@@ -386,14 +437,17 @@ class HtmlDoc(BaseDoc, TextDoc):
             tag = "td"
         self._empty = 1
         if span > 1:
-            self.htmllist += (Html(tag, colspan=str(span), 
-                                    class_=style_name),)
+            self.htmllist += (Html(tag, colspan=str(span), class_=style_name),)
             self._col += span
         else:
-            self.htmllist += (Html(tag, colspan=str(span), 
-                                width=str(self._tbl.get_column_width(
-                                            self._col))+ '%',
-                                class_=style_name),)
+            self.htmllist += (
+                Html(
+                    tag,
+                    colspan=str(span),
+                    width=str(self._tbl.get_column_width(self._col)) + "%",
+                    class_=style_name,
+                ),
+            )
         self._col += 1
 
     def end_cell(self):
@@ -410,26 +464,25 @@ class HtmlDoc(BaseDoc, TextDoc):
         style = style_sheet.get_paragraph_style(style_name)
         level = style.get_header_level()
         if level == 0:
-            #a normal paragraph
-            self.htmllist += (Html('p', class_=style_name, inline=True),)
+            # a normal paragraph
+            self.htmllist += (Html("p", class_=style_name, inline=True),)
         elif level == 1:
-            if self.__title_written == -1 and \
-                    style_name.upper().find('TITLE') != -1:
+            if self.__title_written == -1 and style_name.upper().find("TITLE") != -1:
                 self.__title_written = 0
-                self.htmllist += (Html('div', id="header"),)
-                self.htmllist += (Html('h1', class_=style_name, id='SiteTitle',
-                                       inline=True),)
+                self.htmllist += (Html("div", id="header"),)
+                self.htmllist += (
+                    Html("h1", class_=style_name, id="SiteTitle", inline=True),
+                )
             else:
-                self.htmllist += (Html('h1', class_=style_name, inline=True),)
-        elif 2<= level <= 5:
-            tag = 'h'+str(level+1)
+                self.htmllist += (Html("h1", class_=style_name, inline=True),)
+        elif 2 <= level <= 5:
+            tag = "h" + str(level + 1)
             self.htmllist += (Html(tag, class_=style_name, inline=True),)
         else:
             # a low level header
-            self.htmllist += (Html('div', id='grampsheading',
-                                   class_=style_name),)
+            self.htmllist += (Html("div", id="grampsheading", class_=style_name),)
         if leader is not None:
-            self.write_text(leader+' ')
+            self.write_text(leader + " ")
 
     def end_paragraph(self):
         """
@@ -441,7 +494,7 @@ class HtmlDoc(BaseDoc, TextDoc):
         self.__reduce_list()
         if self.__title_written == 0:
             self.__title_written = 1
-            #close div statement
+            # close div statement
             self.__reduce_list()
             self.write_title()
 
@@ -449,19 +502,19 @@ class HtmlDoc(BaseDoc, TextDoc):
         """
         Overwrite base method
         """
-        self.htmllist += [Html('strong')]
+        self.htmllist += [Html("strong")]
 
     def end_bold(self):
         """
         Overwrite base method
         """
         self.__reduce_list()
-        
+
     def start_superscript(self):
         """
         Overwrite base method
         """
-        self.htmllist += [Html('sup')]
+        self.htmllist += [Html("sup")]
 
     def end_superscript(self):
         """
@@ -469,115 +522,125 @@ class HtmlDoc(BaseDoc, TextDoc):
         """
         self.__reduce_list()
 
-    def write_styled_note(self, styledtext, format, style_name,
-                          contains_html=False, links=False):
+    def write_styled_note(
+        self, styledtext, format, style_name, contains_html=False, links=False
+    ):
         """
-        Convenience function to write a styledtext to the html doc. 
+        Convenience function to write a styledtext to the html doc.
         styledtext : assumed a StyledText object to write
         format : = 0 : Flowed, = 1 : Preformatted
         style_name : name of the style to use for default presentation
-        contains_html: bool, the backend should not check if html is present. 
-            If contains_html=True, then the textdoc is free to handle that in 
+        contains_html: bool, the backend should not check if html is present.
+            If contains_html=True, then the textdoc is free to handle that in
             some way. Eg, a textdoc could remove all tags, or could make sure
-            a link is clickable. HtmlDoc will show the html as pure text, so 
+            a link is clickable. HtmlDoc will show the html as pure text, so
             no escaping will happen.
         links: bool, make URLs clickable if True
         """
         text = str(styledtext)
 
-        self.htmllist += [Html('div', id='grampsstylednote')]
+        self.htmllist += [Html("div", id="grampsstylednote")]
         if contains_html:
-            #just dump the note out as it is. Adding markup would be dangerous
-            # as it could destroy the html. If html code, one can do the 
+            # just dump the note out as it is. Adding markup would be dangerous
+            # as it could destroy the html. If html code, one can do the
             self.start_paragraph(style_name)
             self.__write_text(text, markup=True, links=links)
             self.end_paragraph()
         else:
             s_tags = styledtext.get_tags()
-            markuptext = self._backend.add_markup_from_styled(text, s_tags, 
-                                                              split='\n')
+            markuptext = self._backend.add_markup_from_styled(text, s_tags, split="\n")
             self.start_paragraph(style_name)
             inpara = True
-            self._empty = 1   # para is empty
+            self._empty = 1  # para is empty
             # we explicitly set _empty because start and end para do not seem
             # to do a very good job at setting them
             linenb = 1
             # The code is tricky here, because we don't want to start a new para
             # at the end of the last line if there is no newline there.
             # Instead, we want to just end the current para.
-            for line in markuptext.split('\n'):
+            for line in markuptext.split("\n"):
                 [line, sigcount] = process_spaces(line, format)
                 if sigcount == 0:
-                    if inpara == False:
+                    if inpara is False:
                         # needed for runs of three or more newlines
                         self.start_paragraph(style_name)
                         inpara = True
-                        self._empty = 1   # para is empty
+                        self._empty = 1  # para is empty
                     self.end_paragraph()
                     inpara = False
                     linenb = 1
                 else:
-                    if inpara == False:
+                    if inpara is False:
                         self.start_paragraph(style_name)
                         inpara = True
-                        self._empty = 1   # para is empty
+                        self._empty = 1  # para is empty
                     if linenb > 1:
-                        self.htmllist[-1] += Html('br')
+                        self.htmllist[-1] += Html("br")
                     self.__write_text(line, markup=True, links=links)
                     self._empty = 0  # para is not empty
                     linenb += 1
-            if inpara == True:
+            if inpara is True:
                 self.end_paragraph()
-            if sigcount == 0:        
-                # if the last line was blank, then as well as outputting the previous para,
-                # which we have just done,
-                # we also output a new blank para
+            if sigcount == 0:
+                # if the last line was blank, then as well as outputting the
+                # previous para, which we have just done, we also output a new
+                # blank para
                 self.start_paragraph(style_name)
-                self._empty = 1   # para is empty
+                self._empty = 1  # para is empty
                 self.end_paragraph()
-        #end div element
+        # end div element
         self.__reduce_list()
 
-    def add_media_object(self, name, pos, w_cm, h_cm, alt='', style_name=None, crop=None):
+    def add_media(self, name, pos, w_cm, h_cm, alt="", style_name=None, crop=None):
         """
         Overwrite base method
         """
         self._empty = 0
-        size = int(max(w_cm, h_cm) * float(150.0/2.54))
-        refname = "is%s" % os.path.basename(name)
+        size = int(max(w_cm, h_cm) * float(150.0 / 2.54))
+        if crop:
+            refname = "is-%d-%d-%d-%d-%s" % (
+                crop[0],
+                crop[1],
+                crop[2],
+                crop[3],
+                os.path.basename(name),
+            )
+        else:
+            refname = "is%s" % os.path.basename(name)
 
         imdir = self._backend.datadirfull()
 
         try:
             resize_to_jpeg(name, imdir + os.sep + refname, size, size, crop=crop)
         except:
-            LOG.warn(_("Could not create jpeg version of image %(name)s") % 
-                        {'name' : name})
+            LOG.warning(_("Could not create jpeg version of image %(name)s"), name)
             return
 
         if len(alt):
-            alt = '<br />'.join(alt)
+            alt = "<br />".join(alt)
 
-        if pos not in ["right", "left"] :
+        if pos not in ["right", "left"]:
             if len(alt):
-                self.htmllist[-1] += Html('div') + (
-                    Html('img', src= imdir + os.sep + refname,
-                         border = '0', alt=alt),
-                    Html('p', class_="DDR-Caption") + alt
+                self.htmllist[-1] += Html("div") + (
+                    Html("img", src=imdir + os.sep + refname, border="0", alt=alt),
+                    Html("p", class_="DDR-Caption") + alt,
                 )
             else:
-                self.htmllist[-1] += Html('img', src= imdir + os.sep + refname, 
-                            border = '0', alt=alt)
+                self.htmllist[-1] += Html(
+                    "img", src=imdir + os.sep + refname, border="0", alt=alt
+                )
         else:
             if len(alt):
-                self.htmllist[-1] += Html('div', style_="float: %s; padding: 5px; margin: 0;" % pos) + (
-                    Html('img', src= imdir + os.sep + refname,
-                         border = '0', alt=alt),
-                    Html('p', class_="DDR-Caption") + alt
+                self.htmllist[-1] += Html(
+                    "div", style_="float: %s; padding: 5px; margin: 0;" % pos
+                ) + (
+                    Html("img", src=imdir + os.sep + refname, border="0", alt=alt),
+                    Html("p", class_="DDR-Caption") + alt,
                 )
             else:
-                self.htmllist[-1] += Html('img', src= imdir + os.sep + refname, 
-                            border = '0', alt=alt, align=pos)
+                self.htmllist[-1] += Html(
+                    "img", src=imdir + os.sep + refname, border="0", alt=alt, align=pos
+                )
 
     def page_break(self):
         """
@@ -589,7 +652,7 @@ class HtmlDoc(BaseDoc, TextDoc):
         """
         Starts a section to add a link. Link is a URI.
         """
-        self.htmllist += [Html('a', href=link, **self.__link_attrs)]
+        self.htmllist += [Html("a", href=link, **self.__link_attrs)]
 
     def stop_link(self):
         """
@@ -601,7 +664,7 @@ class HtmlDoc(BaseDoc, TextDoc):
         """
         Starts a section of underlining.
         """
-        self.htmllist += [Html('u')]
+        self.htmllist += [Html("u")]
 
     def stop_underline(self):
         """
