@@ -17,39 +17,59 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
+# -------------------------------------------------------------------------
+#
+# Gtk modules
+#
+# -------------------------------------------------------------------------
+from gi.repository import Gtk
+
+# -------------------------------------------------------------------------
+#
+# Gramps modules
+#
+# -------------------------------------------------------------------------
 from gramps.gui.editors import EditPerson
 from gramps.gui.listmodel import ListModel, NOSORT
 from gramps.gen.plug import Gramplet
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
+from gramps.gen.plug.report.utils import find_spouse
 from gramps.gen.display.name import displayer as name_displayer
 from gramps.gen.utils.db import get_birth_or_fallback, get_death_or_fallback
 from gramps.gen.datehandler import get_date
 from gramps.gen.display.place import displayer as place_displayer
 from gramps.gen.errors import WindowActiveError
-from gi.repository import Gtk
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+from gramps.gui.widgets.persistenttreeview import PersistentTreeView
+
+_ = glocale.translation.gettext
+
 
 class Children(Gramplet):
     """
     Displays the children of a person or family.
     """
+
     def init(self):
         self.gui.WIDGET = self.build_gui()
         self.gui.get_container_widget().remove(self.gui.textview)
         self.gui.get_container_widget().add(self.gui.WIDGET)
         self.gui.WIDGET.show()
-        self.uistate.connect('nameformat-changed', self.update)
+        self.uistate.connect("nameformat-changed", self.update)
+        self.gui.WIDGET.restore_column_size()
+
+    def on_save(self):
+        self.gui.WIDGET.save_column_info()
 
     def get_date_place(self, event):
         """
         Return the date and place of the given event.
         """
-        event_date = ''
-        event_place = ''
-        event_sort = '%012d' % 0
+        event_date = ""
+        event_place = ""
+        event_sort = "%012d" % 0
         if event:
             event_date = get_date(event)
-            event_sort = '%012d' % event.get_date_object().get_sort_value()
+            event_sort = "%012d" % event.get_date_object().get_sort_value()
             event_place = place_displayer.display_event(self.dbstate.db, event)
         return (event_date, event_sort, event_place)
 
@@ -66,35 +86,43 @@ class Children(Gramplet):
             except WindowActiveError:
                 pass
 
+
 class PersonChildren(Children):
     """
     Displays the children of a person.
     """
+
     def build_gui(self):
         """
         Build the GUI interface.
         """
-        tip = _('Double-click on a row to edit the selected child.')
+        tip = _("Double-click on a row to edit the selected child.")
         self.set_tooltip(tip)
-        top = Gtk.TreeView()
-        titles = [('', NOSORT, 50,),
-                  (_('Child'), 1, 250),
-                  (_('Birth Date'), 3, 100),
-                  ('', 3, 100),
-                  (_('Death Date'), 5, 100),
-                  ('', 5, 100),
-                  (_('Spouse'), 6, 250)]
+        top = PersistentTreeView(self.uistate, __name__)
+        titles = [
+            (
+                "",
+                NOSORT,
+                50,
+            ),
+            (_("Child"), 1, 250),
+            (_("Birth Date"), 3, 100),
+            ("", 3, 100),
+            (_("Death Date"), 5, 100),
+            ("", 5, 100),
+            (_("Spouse"), 6, 250),
+        ]
         self.model = ListModel(top, titles, event_func=self.edit_person)
         return top
 
     def db_changed(self):
-        self.dbstate.db.connect('person-update', self.update)
+        self.connect(self.dbstate.db, "person-update", self.update)
 
     def active_changed(self, handle):
         self.update()
 
     def main(self):
-        active_handle = self.get_active('Person')
+        active_handle = self.get_active("Person")
         self.model.clear()
         if active_handle:
             self.display_person(active_handle)
@@ -102,7 +130,7 @@ class PersonChildren(Children):
             self.set_has_data(False)
 
     def update_has_data(self):
-        active_handle = self.get_active('Person')
+        active_handle = self.get_active("Person")
         if active_handle:
             active = self.dbstate.db.get_person_from_handle(active_handle)
             self.set_has_data(self.get_has_data(active))
@@ -128,19 +156,18 @@ class PersonChildren(Children):
         active_person = self.dbstate.db.get_person_from_handle(active_handle)
         for family_handle in active_person.get_family_handle_list():
             family = self.dbstate.db.get_family_from_handle(family_handle)
-            self.display_family(family, active_handle)
+            self.display_family(family, active_person)
         self.set_has_data(self.model.count > 0)
 
-    def display_family(self, family, active_handle):
+    def display_family(self, family, active_person):
         """
         Display the children of given family.
         """
-        father_handle = family.get_father_handle()
-        mother_handle = family.get_mother_handle()
-        if father_handle == active_handle:
-            spouse = self.dbstate.db.get_person_from_handle(mother_handle)
+        spouse_handle = find_spouse(active_person, family)
+        if spouse_handle:
+            spouse = self.dbstate.db.get_person_from_handle(spouse_handle)
         else:
-            spouse = self.dbstate.db.get_person_from_handle(father_handle)
+            spouse = None
 
         for child_ref in family.get_child_ref_list():
             child = self.dbstate.db.get_person_from_handle(child_ref.ref)
@@ -153,47 +180,58 @@ class PersonChildren(Children):
         name = name_displayer.display(child)
         if spouse:
             spouse = name_displayer.display(spouse)
-        spouse = spouse or ''
+        spouse = spouse or ""
         birth = get_birth_or_fallback(self.dbstate.db, child)
         birth_date, birth_sort, birth_place = self.get_date_place(birth)
         death = get_death_or_fallback(self.dbstate.db, child)
         death_date, death_sort, death_place = self.get_date_place(death)
-        self.model.add((child.get_handle(),
-                        name,
-                        birth_date,
-                        birth_sort,
-                        death_date,
-                        death_sort,
-                        spouse))
+        self.model.add(
+            (
+                child.get_handle(),
+                name,
+                birth_date,
+                birth_sort,
+                death_date,
+                death_sort,
+                spouse,
+            )
+        )
+
 
 class FamilyChildren(Children):
     """
     Displays the children of a family.
     """
+
     def build_gui(self):
         """
         Build the GUI interface.
         """
-        tip = _('Double-click on a row to edit the selected child.')
+        tip = _("Double-click on a row to edit the selected child.")
         self.set_tooltip(tip)
-        top = Gtk.TreeView()
-        titles = [('', NOSORT, 50,),
-                  (_('Child'), 1, 250),
-                  (_('Birth Date'), 3, 100),
-                  ('', 3, 100),
-                  (_('Death Date'), 5, 100),
-                  ('', 5, 100)]
+        top = PersistentTreeView(self.uistate, __name__)
+        titles = [
+            (
+                "",
+                NOSORT,
+                50,
+            ),
+            (_("Child"), 1, 250),
+            (_("Birth Date"), 3, 100),
+            ("", 3, 100),
+            (_("Death Date"), 5, 100),
+            ("", 5, 100),
+        ]
         self.model = ListModel(top, titles, event_func=self.edit_person)
         return top
 
     def db_changed(self):
-        self.dbstate.db.connect('family-update', self.update)
-        self.connect_signal('Family', self.update)
-        self.dbstate.db.connect('person-update', self.update)
-        self.connect_signal('Person', self.update)
+        self.connect(self.dbstate.db, "family-update", self.update)
+        self.connect_signal("Family", self.update)  # familiy active-changed
+        self.connect(self.dbstate.db, "person-update", self.update)
 
     def main(self):
-        active_handle = self.get_active('Family')
+        active_handle = self.get_active("Family")
         self.model.clear()
         if active_handle:
             family = self.dbstate.db.get_family_from_handle(active_handle)
@@ -202,7 +240,7 @@ class FamilyChildren(Children):
             self.set_has_data(False)
 
     def update_has_data(self):
-        active_handle = self.get_active('Family')
+        active_handle = self.get_active("Family")
         if active_handle:
             active = self.dbstate.db.get_family_from_handle(active_handle)
             self.set_has_data(self.get_has_data(active))
@@ -237,9 +275,6 @@ class FamilyChildren(Children):
         birth_date, birth_sort, birth_place = self.get_date_place(birth)
         death = get_death_or_fallback(self.dbstate.db, child)
         death_date, death_sort, death_place = self.get_date_place(death)
-        self.model.add((child.get_handle(),
-                        name,
-                        birth_date,
-                        birth_sort,
-                        death_date,
-                        death_sort))
+        self.model.add(
+            (child.get_handle(), name, birth_date, birth_sort, death_date, death_sort)
+        )
