@@ -17,15 +17,28 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
+# -------------------------------------------------------------------------
+#
+# Gtk modules
+#
+# -------------------------------------------------------------------------
+from gi.repository import Gtk
+
+# -------------------------------------------------------------------------
+#
+# Gramps modules
+#
+# -------------------------------------------------------------------------
 from gramps.gen.plug import Gramplet
 from gramps.gui.widgets import Photo
 from gramps.gen.utils.file import media_path_full
-from gi.repository import Gtk
+
 
 class MediaPreview(Gramplet):
     """
     Displays a preview of the media object.
     """
+
     def init(self):
         self.gui.WIDGET = self.build_gui()
         self.gui.get_container_widget().remove(self.gui.textview)
@@ -42,21 +55,21 @@ class MediaPreview(Gramplet):
         return self.top
 
     def db_changed(self):
-        self.dbstate.db.connect('media-update', self.update)
-        self.connect_signal('Media', self.update)
+        self.connect(self.dbstate.db, "media-update", self.update)
+        self.connect_signal("Media", self.update)
 
-    def update_has_data(self): 
-        active_handle = self.get_active('Media')
+    def update_has_data(self):
+        active_handle = self.get_active("Media")
         if active_handle:
-            active_media = self.dbstate.db.get_object_from_handle(active_handle)
+            active_media = self.dbstate.db.get_media_from_handle(active_handle)
             self.set_has_data(active_media is not None)
         else:
             self.set_has_data(False)
 
     def main(self):
-        active_handle = self.get_active('Media')
+        active_handle = self.get_active("Media")
         if active_handle:
-            media = self.dbstate.db.get_object_from_handle(active_handle)
+            media = self.dbstate.db.get_media_from_handle(active_handle)
             self.top.hide()
             if media:
                 self.load_image(media)
@@ -73,7 +86,7 @@ class MediaPreview(Gramplet):
         """
         Load the primary image if it exists.
         """
-        self.full_path = media_path_full(self.dbstate.db,
-                                               media.get_path())
+        self.full_path = media_path_full(self.dbstate.db, media.get_path())
         mime_type = media.get_mime_type()
         self.photo.set_image(self.full_path, mime_type)
+        self.photo.set_uistate(self.uistate, None)
