@@ -24,19 +24,19 @@
 Base view for Place Views
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # GTK/Gnome modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gi.repository import Gdk
 from gi.repository import Gtk
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.lib import Place
 from gramps.gui.views.listview import ListView, TEXT, ICON
 from gramps.gen.errors import WindowActiveError
@@ -45,30 +45,31 @@ from gramps.gen.config import config
 from gramps.gui.dialog import ErrorDialog
 from gramps.gui.pluginmanager import GuiPluginManager
 from gramps.gui.ddtargets import DdTargets
-from gramps.gui.editors import EditPlace, DeletePlaceQuery
+from gramps.gui.editors import EditPlace
 from gramps.gui.filters.sidebar import PlaceSidebarFilter
 from gramps.gui.merge import MergePlace
 from gramps.gen.plug import CATEGORY_QR_PLACE
 from gramps.gen.utils.location import located_in
 from gramps.gui.uimanager import ActionGroup
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # internationalization
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.sgettext
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # PlaceBaseView
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class PlaceBaseView(ListView):
-    """ base view class for place views, be they flat list or tree
-    """
+    """base view class for place views, be they flat list or tree"""
+
     COL_NAME = 0
     COL_ID = 1
     COL_TITLE = 2
@@ -82,24 +83,37 @@ class PlaceBaseView(ListView):
     COL_SEARCH = 11
     # column definitions
     COLUMNS = [
-        (_('Name'), TEXT, None),
-        (_('ID'), TEXT, None),
-        (_('Title'), TEXT, None),
-        (_('Type'), TEXT, None),
-        (_('Code'), TEXT, None),
-        (_('Latitude'), TEXT, None),
-        (_('Longitude'), TEXT, None),
-        (_('Private'), ICON, 'gramps-lock'),
-        (_('Tags'), TEXT, None),
-        (_('Last Changed'), TEXT, None),
-        ]
+        (_("Name"), TEXT, None),
+        (_("ID"), TEXT, None),
+        (_("Title"), TEXT, None),
+        (_("Type"), TEXT, None),
+        (_("Code"), TEXT, None),
+        (_("Latitude"), TEXT, None),
+        (_("Longitude"), TEXT, None),
+        (_("Private"), ICON, "gramps-lock"),
+        (_("Tags"), TEXT, None),
+        (_("Last Changed"), TEXT, None),
+    ]
     # default setting with visible columns, order of the col, and their size
     CONFIGSETTINGS = (
-        ('columns.visible', [COL_NAME, COL_ID, COL_TYPE, COL_CODE]),
-        ('columns.rank', [COL_NAME, COL_TITLE, COL_ID, COL_TYPE, COL_CODE,
-                          COL_LAT, COL_LON, COL_PRIV, COL_TAGS, COL_CHAN]),
-        ('columns.size', [250, 250, 75, 100, 100, 150, 150, 40, 100, 100])
-        )
+        ("columns.visible", [COL_NAME, COL_ID, COL_TYPE, COL_CODE]),
+        (
+            "columns.rank",
+            [
+                COL_NAME,
+                COL_TITLE,
+                COL_ID,
+                COL_TYPE,
+                COL_CODE,
+                COL_LAT,
+                COL_LON,
+                COL_PRIV,
+                COL_TAGS,
+                COL_CHAN,
+            ],
+        ),
+        ("columns.size", [250, 250, 75, 100, 100, 150, 150, 40, 100, 100]),
+    )
     ADD_MSG = _("Add a new place")
     EDIT_MSG = _("Edit the selected place")
     DEL_MSG = _("Delete the selected place")
@@ -108,47 +122,59 @@ class PlaceBaseView(ListView):
     QR_CATEGORY = CATEGORY_QR_PLACE
 
     def __init__(self, pdata, dbstate, uistate, title, model, nav_group):
-
         signal_map = {
-            'place-add'     : self.row_add,
-            'place-update'  : self.row_update,
-            'place-delete'  : self.row_delete,
-            'place-rebuild' : self.object_build,
-            }
+            "place-add": self.row_add,
+            "place-update": self.row_update,
+            "place-delete": self.row_delete,
+            "place-rebuild": self.object_build,
+        }
 
-        self.mapservice = config.get('interface.mapservice')
+        self.mapservice = config.get("interface.mapservice")
         self.mapservicedata = {}
         self.map_action_group = None
 
         ListView.__init__(
-            self, title, pdata, dbstate, uistate,
-            model, signal_map,
-            PlaceBookmarks, nav_group,
+            self,
+            title,
+            pdata,
+            dbstate,
+            uistate,
+            model,
+            signal_map,
+            PlaceBookmarks,
+            nav_group,
             multiple=True,
-            filter_class=PlaceSidebarFilter)
+            filter_class=PlaceSidebarFilter,
+        )
 
-        uistate.connect('placeformat-changed', self.build_tree)
+        uistate.connect("placeformat-changed", self.build_tree)
 
         _ui = self.__create_maps_menu_actions()
         self.additional_uis.append(_ui)
 
     def navigation_type(self):
-        return 'Place'
+        return "Place"
 
-    def setup_filter(self):
-        """Build the default filters and add them to the filter menu.
+    def setup_searches(self):
+        """Build the default searches and add them to the search bar.
         This overrides the listview method because we use the hidden
         COL_SEARCH that has alt names as well as primary name for name
         searching"""
-        self.search_bar.setup_filter(
-            [(self.COLUMNS[pair[1]][0],
-              self.COL_SEARCH if pair[1] == self.COL_NAME else pair[1],
-              pair[1] in self.exact_search())
-                for pair in self.column_order() if pair[0]])
+        self.search_bar.setup_searches(
+            [
+                (
+                    self.COLUMNS[pair[1]][0],
+                    self.COL_SEARCH if pair[1] == self.COL_NAME else pair[1],
+                    pair[1] in self.exact_search(),
+                )
+                for pair in self.column_order()
+                if pair[0]
+            ]
+        )
 
     def define_actions(self):
         ListView.define_actions(self)
-        self._add_action('GotoMap', self.gotomap)
+        self._add_action("GotoMap", self.gotomap)
 
     def change_page(self):
         """
@@ -167,31 +193,30 @@ class PlaceBaseView(ListView):
         Function creating a menu and actions that are used as dropdown menu
         from the menutoolbutton
         """
-        _bar = '''
+        _bar = """
             <item>
               <attribute name="action">win.MapChoice</attribute>
               <attribute name="target">%s</attribute>
               <attribute name="label">%s</attribute>
             </item>
-            '''
-        menu = ''
+            """
+        menu = ""
 
-        #select the map services to show
+        # select the map services to show
         self.mapservicedata = {}
         servlist = GuiPluginManager.get_instance().get_reg_mapservices()
         for pdata in servlist:
-            key = pdata.id.replace(' ', '-')
+            key = pdata.id.replace(" ", "-")
             menu += _bar % (key, pdata.name)
             self.mapservicedata[key] = pdata
 
         if not self.mapservicedata:
             return self.additional_ui
         if self.mapservice not in self.mapservicedata:
-            #stored val no longer exists, use the most recent key instead
+            # stored val no longer exists, use the most recent key instead
             self.set_mapservice(None, key)
 
-        self._add_toggle_action('MapChoice', self.set_mapservice, '',
-                                self.mapservice)
+        self._add_toggle_action("MapChoice", self.set_mapservice, "", self.mapservice)
 
         label = self.mapservice_label()
         _ui = self.additional_ui[:]
@@ -209,7 +234,7 @@ class PlaceBaseView(ListView):
             self.mapservice = value.get_string()
         else:
             self.mapservice = value
-        config.set('interface.mapservice', self.mapservice)
+        config.set("interface.mapservice", self.mapservice)
         config.save()
         _ui = self.__create_maps_menu_actions()
         self.uimanager.add_ui_from_string(_ui)
@@ -226,7 +251,7 @@ class PlaceBaseView(ListView):
         """
         Run the map service
         """
-        #First test if any map service is available
+        # First test if any map service is available
         if not len(self.mapservicedata):
             msg = _("No map service is available.")
             msg2 = _("Check your installation.")
@@ -238,17 +263,19 @@ class PlaceBaseView(ListView):
             place_handle = self.selected_handles()[0]
         except IndexError:
             msg = _("No place selected.")
-            msg2 = _("You need to select a place to be able to view it"
-                     " on a map. Some Map Services might support multiple"
-                     " selections.")
+            msg2 = _(
+                "You need to select a place to be able to view it"
+                " on a map. Some Map Services might support multiple"
+                " selections."
+            )
             ErrorDialog(msg, msg2, parent=self.uistate.window)
             return
 
-        #TODO: support for descriptions in some cases. For now, pass None
-        #TODO: Later this might be 'Birth of William' ....
+        # TODO: support for descriptions in some cases. For now, pass None
+        # TODO: Later this might be 'Birth of William' ....
         places = [(x, None) for x in place_handles]
 
-        #run the mapservice:
+        # run the mapservice:
         pmgr = GuiPluginManager.get_instance()
         serv = self.mapservicedata[self.mapservice]
         mod = pmgr.load_plugin(serv)
@@ -256,27 +283,27 @@ class PlaceBaseView(ListView):
             servfunc = getattr(mod, serv.mapservice)
             servfunc()(self.dbstate.db, places, self.uistate)
         else:
-            print('Failed to load map plugin, see Plugin Manager')
+            print("Failed to load map plugin, see Plugin Manager")
 
     def drag_info(self):
         return DdTargets.PLACE_LINK
 
     def get_stock(self):
-        return 'gramps-place'
+        return "gramps-place"
 
     #
     # Defines the UI string for UIManager
     #
     additional_ui = [
-        '''
+        """
       <placeholder id="LocalExport">
         <item>
           <attribute name="action">win.ExportTab</attribute>
           <attribute name="label" translatable="yes">Export View...</attribute>
         </item>
       </placeholder>
-''',
-        '''
+""",
+        """
       <section id="AddEditBook">
         <item>
           <attribute name="action">win.AddBook</attribute>
@@ -287,8 +314,9 @@ class PlaceBaseView(ListView):
           <attribute name="label" translatable="no">%s...</attribute>
         </item>
       </section>
-''' % _('Organize Bookmarks'),
-        '''
+"""
+        % _("Organize Bookmarks"),
+        """
       <placeholder id="CommonGo">
       <section>
         <item>
@@ -301,8 +329,8 @@ class PlaceBaseView(ListView):
         </item>
       </section>
       </placeholder>
-''',
-        '''
+""",
+        """
       <section id='CommonEdit' groups='RW'>
         <item>
           <attribute name="action">win.Add</attribute>
@@ -321,24 +349,25 @@ class PlaceBaseView(ListView):
           <attribute name="label" translatable="yes">_Merge...</attribute>
         </item>
       </section>
-''' % _("action|_Edit..."),  # to use sgettext()
-        '''
+"""
+        % _("_Edit...", "action"),  # to use sgettext()
+        """
         <placeholder id='otheredit'>
         <item>
           <attribute name="action">win.FilterEdit</attribute>
-          <attribute name="label" translatable="yes">'''
-        '''Place Filter Editor</attribute>
+          <attribute name="label" translatable="yes">"""
+        """Place Filter Editor</attribute>
         </item>
         </placeholder>
-''',  # Following are the Toolbar items
-        '''
+""",  # Following are the Toolbar items
+        """
     <placeholder id='CommonNavigation'>
     <child groups='RO'>
       <object class="GtkToolButton">
         <property name="icon-name">go-previous</property>
         <property name="action-name">win.Back</property>
-        <property name="tooltip_text" translatable="yes">'''
-        '''Go to the previous object in the history</property>
+        <property name="tooltip_text" translatable="yes">"""
+        """Go to the previous object in the history</property>
         <property name="label" translatable="yes">_Back</property>
         <property name="use-underline">True</property>
       </object>
@@ -350,8 +379,8 @@ class PlaceBaseView(ListView):
       <object class="GtkToolButton">
         <property name="icon-name">go-next</property>
         <property name="action-name">win.Forward</property>
-        <property name="tooltip_text" translatable="yes">'''
-        '''Go to the next object in the history</property>
+        <property name="tooltip_text" translatable="yes">"""
+        """Go to the next object in the history</property>
         <property name="label" translatable="yes">_Forward</property>
         <property name="use-underline">True</property>
       </object>
@@ -360,8 +389,8 @@ class PlaceBaseView(ListView):
       </packing>
     </child>
     </placeholder>
-''',
-        '''
+""",
+        """
     <placeholder id='BarCommonEdit'>
     <child groups='RW'>
       <object class="GtkToolButton">
@@ -413,8 +442,9 @@ class PlaceBaseView(ListView):
     </child>
     <placeholder id="PlaceMapUi"> </placeholder>
     </placeholder>
-''' % (ADD_MSG, EDIT_MSG, DEL_MSG, MERGE_MSG),
-        '''
+"""
+        % (ADD_MSG, EDIT_MSG, DEL_MSG, MERGE_MSG),
+        """
     <menu id="Popup">
       <section id="PopUpTree">
         <item>
@@ -447,32 +477,36 @@ class PlaceBaseView(ListView):
       <section>
         <placeholder id='QuickReport'>
         </placeholder>
+        <placeholder id='WebConnect'>
+        </placeholder>
       </section>
       <section>
         <item>
           <attribute name="action">win.GotoMap</attribute>
-          <attribute name="label" translatable="yes">'''
-        '''_Look up with Map Service</attribute>
+          <attribute name="label" translatable="yes">"""
+        """_Look up with Map Service</attribute>
         </item>
       </section>
     </menu>
-''' % _('action|_Edit...')]  # to use sgettext()
+"""
+        % _("_Edit...", "action"),
+    ]  # to use sgettext()
 
-    map_ui_menu = '''
+    map_ui_menu = """
       <menu id="MapBtnMenu">
         %s
       </menu>
-    '''
+    """
 
     map_ui = (
-        '''<placeholder id="PlaceMapUi">
+        """<placeholder id="PlaceMapUi">
     <child>
       <object class="GtkToolButton" id="GotoMap">
         <property name="icon-name">go-jump</property>
         <property name="action-name">win.GotoMap</property>
-        <property name="tooltip_text" translatable="yes">'''
-        '''Attempt to see selected locations with a Map Service '''
-        '''(OpenstreetMap, Google Maps, ...)</property>
+        <property name="tooltip_text" translatable="yes">"""
+        """Attempt to see selected locations with a Map Service """
+        """(OpenstreetMap, Google Maps, ...)</property>
         <property name="label">%s</property>
         <property name="use-underline">True</property>
       </object>
@@ -484,8 +518,8 @@ class PlaceBaseView(ListView):
       <object class="GtkToolItem">
         <child>
           <object class="GtkMenuButton">
-            <property name="tooltip_text" translatable="yes">'''
-        '''Select a Map Service</property>
+            <property name="tooltip_text" translatable="yes">"""
+        """Select a Map Service</property>
             <property name="menu-model">MapBtnMenu</property>
             <property name="relief">GTK_RELIEF_NONE</property>
             <property name="use-popover">False</property>
@@ -494,7 +528,8 @@ class PlaceBaseView(ListView):
       </object>
     </child>
     </placeholder>
-    ''')
+    """
+    )
 
     def add(self, *obj):
         try:
@@ -503,34 +538,18 @@ class PlaceBaseView(ListView):
             pass
 
     def remove(self, *obj):
+        ht_list = []
         for handle in self.selected_handles():
-            for link in self.dbstate.db.find_backlink_handles(handle,['Place']):
+            for _link in self.dbstate.db.find_backlink_handles(handle, ["Place"]):
                 msg = _("Cannot delete place.")
-                msg2 = _("This place is currently referenced by another place. "
-                         "First remove the places it contains.")
+                msg2 = _(
+                    "This place is currently referenced by another place."
+                    " First remove the places it contains."
+                )
                 ErrorDialog(msg, msg2, parent=self.uistate.window)
                 return
-        self.remove_selected_objects()
-
-    def remove_object_from_handle(self, handle):
-        person_list = [
-            item[1] for item in
-            self.dbstate.db.find_backlink_handles(handle,['Person'])]
-
-        family_list = [
-            item[1] for item in
-            self.dbstate.db.find_backlink_handles(handle,['Family'])]
-
-        event_list = [
-            item[1] for item in
-            self.dbstate.db.find_backlink_handles(handle,['Event'])]
-
-        object = self.dbstate.db.get_place_from_handle(handle)
-        query = DeletePlaceQuery(self.dbstate, self.uistate, object,
-                                 person_list, family_list, event_list)
-
-        is_used = len(person_list) + len(family_list) + len(event_list) > 0
-        return (query, is_used, object)
+            ht_list.append(("Place", handle))
+        self.remove_selected_objects(ht_list)
 
     def edit(self, *obj):
         for handle in self.selected_handles():
@@ -548,20 +567,26 @@ class PlaceBaseView(ListView):
 
         if len(mlist) != 2:
             msg = _("Cannot merge places.")
-            msg2 = _("Exactly two places must be selected to perform a merge. "
-                     "A second place can be selected by holding down the "
-                     "control key while clicking on the desired place.")
+            msg2 = _(
+                "Exactly two places must be selected to perform a merge. "
+                "A second place can be selected by holding down the "
+                "control key while clicking on the desired place."
+            )
             ErrorDialog(msg, msg2, parent=self.uistate.window)
         else:
-            if (located_in(self.dbstate.db, mlist[0], mlist[1]) or
-                located_in(self.dbstate.db, mlist[1], mlist[0])):
+            if located_in(self.dbstate.db, mlist[0], mlist[1]) or located_in(
+                self.dbstate.db, mlist[1], mlist[0]
+            ):
                 msg = _("Cannot merge places.")
-                msg2 = _("Merging these places would create a cycle in the "
-                         "place hierarchy.")
+                msg2 = _(
+                    "Merging these places would create a cycle in the "
+                    "place hierarchy."
+                )
                 ErrorDialog(msg, msg2, parent=self.uistate.window)
             else:
-                MergePlace(self.dbstate, self.uistate, [], mlist[0], mlist[1],
-                           self.merged)
+                MergePlace(
+                    self.dbstate, self.uistate, [], mlist[0], mlist[1], self.merged
+                )
 
     def merged(self):
         """
@@ -583,9 +608,14 @@ class PlaceBaseView(ListView):
         """
         all_links = set([])
         for tag_handle in handle_list:
-            links = set([link[1] for link in
-                         self.dbstate.db.find_backlink_handles(tag_handle,
-                                                    include_classes='Place')])
+            links = set(
+                [
+                    link[1]
+                    for link in self.dbstate.db.find_backlink_handles(
+                        tag_handle, include_classes="Place"
+                    )
+                ]
+            )
             all_links = all_links.union(links)
         self.row_update(list(all_links))
 
@@ -597,18 +627,30 @@ class PlaceBaseView(ListView):
         place.add_tag(tag_handle)
         self.dbstate.db.commit_place(place, transaction)
 
+    def remove_tag(self, transaction, place_handle, tag_handle):
+        """
+        Remove the given tag from the given place.
+        """
+        place = self.dbstate.db.get_place_from_handle(place_handle)
+        place.remove_tag(tag_handle)
+        self.dbstate.db.commit_place(place, transaction)
+
     def get_default_gramplets(self):
         """
         Define the default gramplets for the sidebar and bottombar.
         """
-        return (("Place Filter",),
-                ("Place Details",
-                 "Place Enclosed By",
-                 "Place Encloses",
-                 "Place Gallery",
-                 "Place Citations",
-                 "Place Notes",
-                 "Place Backlinks"))
+        return (
+            ("Place Filter",),
+            (
+                "Place Details",
+                "Place Enclosed By",
+                "Place Encloses",
+                "Place Gallery",
+                "Place Citations",
+                "Place Notes",
+                "Place Backlinks",
+            ),
+        )
 
 
 def make_callback(func, val):
