@@ -19,8 +19,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-"""The core library of Gramps objects
-"""
+"""The core library of Gramps objects"""
 # Dates
 from .date import Date, DateError, Span
 
@@ -32,14 +31,13 @@ from .attribute import Attribute
 from .srcattribute import SrcAttribute
 from .eventref import EventRef
 from .ldsord import LdsOrd
-from .mediaref import MediaRef 
+from .mediaref import MediaRef
 from .name import Name
 from .placename import PlaceName
 from .placeref import PlaceRef
 from .reporef import RepoRef
 from .surname import Surname
 from .url import Url
-from .witness import Witness
 from .childref import ChildRef
 
 # Primary objects
@@ -50,7 +48,7 @@ from .family import Family
 from .event import Event
 from .place import Place
 from .src import Source
-from .mediaobj import MediaObject
+from .media import Media
 from .repo import Repository
 from .note import Note
 from .citation import Citation
