@@ -19,41 +19,42 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # internationalization
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.sgettext
 from ..views.treemodels import RepositoryModel
 from .baseselector import BaseSelector
 from gramps.gen.const import URL_MANUAL_SECT2
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Constants
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # SelectRepository
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class SelectRepository(BaseSelector):
-
     def _local_init(self):
         """
         Perform local initialisation for this class
         """
-        self.setup_configs('interface.repo-sel', 600, 450)
+        self.setup_configs("interface.repo-sel", 600, 450)
 
     def get_window_title(self):
         return _("Select Repository")
@@ -63,13 +64,16 @@ class SelectRepository(BaseSelector):
 
     def get_column_titles(self):
         return [
-            (_('Title'), 350, BaseSelector.TEXT, 0),
-            (_('ID'),     75, BaseSelector.TEXT, 1),
-            (_('Last Change'), 150, BaseSelector.TEXT, 14),
-            ]
+            (_("Title"), 350, BaseSelector.TEXT, 0),
+            (_("ID"), 75, BaseSelector.TEXT, 1),
+            (_("Last Change"), 150, BaseSelector.TEXT, 14),
+        ]
 
     def get_from_handle_func(self):
         return self.db.get_repository_from_handle
 
+    def get_config_name(self):
+        return __name__
+
     WIKI_HELP_PAGE = URL_MANUAL_SECT2
-    WIKI_HELP_SEC = _('manual|Select_Repository_selector')
+    WIKI_HELP_SEC = _("Select_Repository_selector", "manual")
